# ----------------------------------------------------------------------------
# pyglet
# Copyright (c) 2006-2008 Alex Holkner
# Copyright (c) 2008-2020 pyglet contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
#  * Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#  * Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
#  * Neither the name of pyglet nor the names of its
#    contributors may be used to endorse or promote products
#    derived from this software without specific prior written
#    permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
# COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.
# ----------------------------------------------------------------------------
"""Wrapper for /usr/include/GL/gl.h

Generated by tools/gengl.py.
Do not modify this file.
"""

__docformat__ = 'restructuredtext'
__version__ = '$Id$'

from ctypes import *
from pyglet.gl.lib import link_GL as _link_function
from pyglet.gl.lib import c_ptrdiff_t

# BEGIN GENERATED CONTENT (do not edit below this line)

# This content is generated by tools/gengl.py.
# Wrapper for /usr/include/GL/gl.h


GL_VERSION_1_1 = 1 	# /usr/include/GL/gl.h:112
GL_VERSION_1_2 = 1 	# /usr/include/GL/gl.h:113
GL_VERSION_1_3 = 1 	# /usr/include/GL/gl.h:114
GL_ARB_imaging = 1 	# /usr/include/GL/gl.h:115
GLenum = c_uint 	# /usr/include/GL/gl.h:121
GLboolean = c_ubyte 	# /usr/include/GL/gl.h:122
GLbitfield = c_uint 	# /usr/include/GL/gl.h:123
GLvoid = None 	# /usr/include/GL/gl.h:124
GLbyte = c_char 	# /usr/include/GL/gl.h:125
GLshort = c_short 	# /usr/include/GL/gl.h:126
GLint = c_int 	# /usr/include/GL/gl.h:127
GLubyte = c_ubyte 	# /usr/include/GL/gl.h:128
GLushort = c_ushort 	# /usr/include/GL/gl.h:129
GLuint = c_uint 	# /usr/include/GL/gl.h:130
GLsizei = c_int 	# /usr/include/GL/gl.h:131
GLfloat = c_float 	# /usr/include/GL/gl.h:132
GLclampf = c_float 	# /usr/include/GL/gl.h:133
GLdouble = c_double 	# /usr/include/GL/gl.h:134
GLclampd = c_double 	# /usr/include/GL/gl.h:135
GL_FALSE = 0 	# /usr/include/GL/gl.h:144
GL_TRUE = 1 	# /usr/include/GL/gl.h:145
GL_BYTE = 5120 	# /usr/include/GL/gl.h:148
GL_UNSIGNED_BYTE = 5121 	# /usr/include/GL/gl.h:149
GL_SHORT = 5122 	# /usr/include/GL/gl.h:150
GL_UNSIGNED_SHORT = 5123 	# /usr/include/GL/gl.h:151
GL_INT = 5124 	# /usr/include/GL/gl.h:152
GL_UNSIGNED_INT = 5125 	# /usr/include/GL/gl.h:153
GL_FLOAT = 5126 	# /usr/include/GL/gl.h:154
GL_2_BYTES = 5127 	# /usr/include/GL/gl.h:155
GL_3_BYTES = 5128 	# /usr/include/GL/gl.h:156
GL_4_BYTES = 5129 	# /usr/include/GL/gl.h:157
GL_DOUBLE = 5130 	# /usr/include/GL/gl.h:158
GL_POINTS = 0 	# /usr/include/GL/gl.h:161
GL_LINES = 1 	# /usr/include/GL/gl.h:162
GL_LINE_LOOP = 2 	# /usr/include/GL/gl.h:163
GL_LINE_STRIP = 3 	# /usr/include/GL/gl.h:164
GL_TRIANGLES = 4 	# /usr/include/GL/gl.h:165
GL_TRIANGLE_STRIP = 5 	# /usr/include/GL/gl.h:166
GL_TRIANGLE_FAN = 6 	# /usr/include/GL/gl.h:167
GL_QUADS = 7 	# /usr/include/GL/gl.h:168
GL_QUAD_STRIP = 8 	# /usr/include/GL/gl.h:169
GL_POLYGON = 9 	# /usr/include/GL/gl.h:170
GL_VERTEX_ARRAY = 32884 	# /usr/include/GL/gl.h:173
GL_NORMAL_ARRAY = 32885 	# /usr/include/GL/gl.h:174
GL_COLOR_ARRAY = 32886 	# /usr/include/GL/gl.h:175
GL_INDEX_ARRAY = 32887 	# /usr/include/GL/gl.h:176
GL_TEXTURE_COORD_ARRAY = 32888 	# /usr/include/GL/gl.h:177
GL_EDGE_FLAG_ARRAY = 32889 	# /usr/include/GL/gl.h:178
GL_VERTEX_ARRAY_SIZE = 32890 	# /usr/include/GL/gl.h:179
GL_VERTEX_ARRAY_TYPE = 32891 	# /usr/include/GL/gl.h:180
GL_VERTEX_ARRAY_STRIDE = 32892 	# /usr/include/GL/gl.h:181
GL_NORMAL_ARRAY_TYPE = 32894 	# /usr/include/GL/gl.h:182
GL_NORMAL_ARRAY_STRIDE = 32895 	# /usr/include/GL/gl.h:183
GL_COLOR_ARRAY_SIZE = 32897 	# /usr/include/GL/gl.h:184
GL_COLOR_ARRAY_TYPE = 32898 	# /usr/include/GL/gl.h:185
GL_COLOR_ARRAY_STRIDE = 32899 	# /usr/include/GL/gl.h:186
GL_INDEX_ARRAY_TYPE = 32901 	# /usr/include/GL/gl.h:187
GL_INDEX_ARRAY_STRIDE = 32902 	# /usr/include/GL/gl.h:188
GL_TEXTURE_COORD_ARRAY_SIZE = 32904 	# /usr/include/GL/gl.h:189
GL_TEXTURE_COORD_ARRAY_TYPE = 32905 	# /usr/include/GL/gl.h:190
GL_TEXTURE_COORD_ARRAY_STRIDE = 32906 	# /usr/include/GL/gl.h:191
GL_EDGE_FLAG_ARRAY_STRIDE = 32908 	# /usr/include/GL/gl.h:192
GL_VERTEX_ARRAY_POINTER = 32910 	# /usr/include/GL/gl.h:193
GL_NORMAL_ARRAY_POINTER = 32911 	# /usr/include/GL/gl.h:194
GL_COLOR_ARRAY_POINTER = 32912 	# /usr/include/GL/gl.h:195
GL_INDEX_ARRAY_POINTER = 32913 	# /usr/include/GL/gl.h:196
GL_TEXTURE_COORD_ARRAY_POINTER = 32914 	# /usr/include/GL/gl.h:197
GL_EDGE_FLAG_ARRAY_POINTER = 32915 	# /usr/include/GL/gl.h:198
GL_V2F = 10784 	# /usr/include/GL/gl.h:199
GL_V3F = 10785 	# /usr/include/GL/gl.h:200
GL_C4UB_V2F = 10786 	# /usr/include/GL/gl.h:201
GL_C4UB_V3F = 10787 	# /usr/include/GL/gl.h:202
GL_C3F_V3F = 10788 	# /usr/include/GL/gl.h:203
GL_N3F_V3F = 10789 	# /usr/include/GL/gl.h:204
GL_C4F_N3F_V3F = 10790 	# /usr/include/GL/gl.h:205
GL_T2F_V3F = 10791 	# /usr/include/GL/gl.h:206
GL_T4F_V4F = 10792 	# /usr/include/GL/gl.h:207
GL_T2F_C4UB_V3F = 10793 	# /usr/include/GL/gl.h:208
GL_T2F_C3F_V3F = 10794 	# /usr/include/GL/gl.h:209
GL_T2F_N3F_V3F = 10795 	# /usr/include/GL/gl.h:210
GL_T2F_C4F_N3F_V3F = 10796 	# /usr/include/GL/gl.h:211
GL_T4F_C4F_N3F_V4F = 10797 	# /usr/include/GL/gl.h:212
GL_MATRIX_MODE = 2976 	# /usr/include/GL/gl.h:215
GL_MODELVIEW = 5888 	# /usr/include/GL/gl.h:216
GL_PROJECTION = 5889 	# /usr/include/GL/gl.h:217
GL_TEXTURE = 5890 	# /usr/include/GL/gl.h:218
GL_POINT_SMOOTH = 2832 	# /usr/include/GL/gl.h:221
GL_POINT_SIZE = 2833 	# /usr/include/GL/gl.h:222
GL_POINT_SIZE_GRANULARITY = 2835 	# /usr/include/GL/gl.h:223
GL_POINT_SIZE_RANGE = 2834 	# /usr/include/GL/gl.h:224
GL_LINE_SMOOTH = 2848 	# /usr/include/GL/gl.h:227
GL_LINE_STIPPLE = 2852 	# /usr/include/GL/gl.h:228
GL_LINE_STIPPLE_PATTERN = 2853 	# /usr/include/GL/gl.h:229
GL_LINE_STIPPLE_REPEAT = 2854 	# /usr/include/GL/gl.h:230
GL_LINE_WIDTH = 2849 	# /usr/include/GL/gl.h:231
GL_LINE_WIDTH_GRANULARITY = 2851 	# /usr/include/GL/gl.h:232
GL_LINE_WIDTH_RANGE = 2850 	# /usr/include/GL/gl.h:233
GL_POINT = 6912 	# /usr/include/GL/gl.h:236
GL_LINE = 6913 	# /usr/include/GL/gl.h:237
GL_FILL = 6914 	# /usr/include/GL/gl.h:238
GL_CW = 2304 	# /usr/include/GL/gl.h:239
GL_CCW = 2305 	# /usr/include/GL/gl.h:240
GL_FRONT = 1028 	# /usr/include/GL/gl.h:241
GL_BACK = 1029 	# /usr/include/GL/gl.h:242
GL_POLYGON_MODE = 2880 	# /usr/include/GL/gl.h:243
GL_POLYGON_SMOOTH = 2881 	# /usr/include/GL/gl.h:244
GL_POLYGON_STIPPLE = 2882 	# /usr/include/GL/gl.h:245
GL_EDGE_FLAG = 2883 	# /usr/include/GL/gl.h:246
GL_CULL_FACE = 2884 	# /usr/include/GL/gl.h:247
GL_CULL_FACE_MODE = 2885 	# /usr/include/GL/gl.h:248
GL_FRONT_FACE = 2886 	# /usr/include/GL/gl.h:249
GL_POLYGON_OFFSET_FACTOR = 32824 	# /usr/include/GL/gl.h:250
GL_POLYGON_OFFSET_UNITS = 10752 	# /usr/include/GL/gl.h:251
GL_POLYGON_OFFSET_POINT = 10753 	# /usr/include/GL/gl.h:252
GL_POLYGON_OFFSET_LINE = 10754 	# /usr/include/GL/gl.h:253
GL_POLYGON_OFFSET_FILL = 32823 	# /usr/include/GL/gl.h:254
GL_COMPILE = 4864 	# /usr/include/GL/gl.h:257
GL_COMPILE_AND_EXECUTE = 4865 	# /usr/include/GL/gl.h:258
GL_LIST_BASE = 2866 	# /usr/include/GL/gl.h:259
GL_LIST_INDEX = 2867 	# /usr/include/GL/gl.h:260
GL_LIST_MODE = 2864 	# /usr/include/GL/gl.h:261
GL_NEVER = 512 	# /usr/include/GL/gl.h:264
GL_LESS = 513 	# /usr/include/GL/gl.h:265
GL_EQUAL = 514 	# /usr/include/GL/gl.h:266
GL_LEQUAL = 515 	# /usr/include/GL/gl.h:267
GL_GREATER = 516 	# /usr/include/GL/gl.h:268
GL_NOTEQUAL = 517 	# /usr/include/GL/gl.h:269
GL_GEQUAL = 518 	# /usr/include/GL/gl.h:270
GL_ALWAYS = 519 	# /usr/include/GL/gl.h:271
GL_DEPTH_TEST = 2929 	# /usr/include/GL/gl.h:272
GL_DEPTH_BITS = 3414 	# /usr/include/GL/gl.h:273
GL_DEPTH_CLEAR_VALUE = 2931 	# /usr/include/GL/gl.h:274
GL_DEPTH_FUNC = 2932 	# /usr/include/GL/gl.h:275
GL_DEPTH_RANGE = 2928 	# /usr/include/GL/gl.h:276
GL_DEPTH_WRITEMASK = 2930 	# /usr/include/GL/gl.h:277
GL_DEPTH_COMPONENT = 6402 	# /usr/include/GL/gl.h:278
GL_LIGHTING = 2896 	# /usr/include/GL/gl.h:281
GL_LIGHT0 = 16384 	# /usr/include/GL/gl.h:282
GL_LIGHT1 = 16385 	# /usr/include/GL/gl.h:283
GL_LIGHT2 = 16386 	# /usr/include/GL/gl.h:284
GL_LIGHT3 = 16387 	# /usr/include/GL/gl.h:285
GL_LIGHT4 = 16388 	# /usr/include/GL/gl.h:286
GL_LIGHT5 = 16389 	# /usr/include/GL/gl.h:287
GL_LIGHT6 = 16390 	# /usr/include/GL/gl.h:288
GL_LIGHT7 = 16391 	# /usr/include/GL/gl.h:289
GL_SPOT_EXPONENT = 4613 	# /usr/include/GL/gl.h:290
GL_SPOT_CUTOFF = 4614 	# /usr/include/GL/gl.h:291
GL_CONSTANT_ATTENUATION = 4615 	# /usr/include/GL/gl.h:292
GL_LINEAR_ATTENUATION = 4616 	# /usr/include/GL/gl.h:293
GL_QUADRATIC_ATTENUATION = 4617 	# /usr/include/GL/gl.h:294
GL_AMBIENT = 4608 	# /usr/include/GL/gl.h:295
GL_DIFFUSE = 4609 	# /usr/include/GL/gl.h:296
GL_SPECULAR = 4610 	# /usr/include/GL/gl.h:297
GL_SHININESS = 5633 	# /usr/include/GL/gl.h:298
GL_EMISSION = 5632 	# /usr/include/GL/gl.h:299
GL_POSITION = 4611 	# /usr/include/GL/gl.h:300
GL_SPOT_DIRECTION = 4612 	# /usr/include/GL/gl.h:301
GL_AMBIENT_AND_DIFFUSE = 5634 	# /usr/include/GL/gl.h:302
GL_COLOR_INDEXES = 5635 	# /usr/include/GL/gl.h:303
GL_LIGHT_MODEL_TWO_SIDE = 2898 	# /usr/include/GL/gl.h:304
GL_LIGHT_MODEL_LOCAL_VIEWER = 2897 	# /usr/include/GL/gl.h:305
GL_LIGHT_MODEL_AMBIENT = 2899 	# /usr/include/GL/gl.h:306
GL_FRONT_AND_BACK = 1032 	# /usr/include/GL/gl.h:307
GL_SHADE_MODEL = 2900 	# /usr/include/GL/gl.h:308
GL_FLAT = 7424 	# /usr/include/GL/gl.h:309
GL_SMOOTH = 7425 	# /usr/include/GL/gl.h:310
GL_COLOR_MATERIAL = 2903 	# /usr/include/GL/gl.h:311
GL_COLOR_MATERIAL_FACE = 2901 	# /usr/include/GL/gl.h:312
GL_COLOR_MATERIAL_PARAMETER = 2902 	# /usr/include/GL/gl.h:313
GL_NORMALIZE = 2977 	# /usr/include/GL/gl.h:314
GL_CLIP_PLANE0 = 12288 	# /usr/include/GL/gl.h:317
GL_CLIP_PLANE1 = 12289 	# /usr/include/GL/gl.h:318
GL_CLIP_PLANE2 = 12290 	# /usr/include/GL/gl.h:319
GL_CLIP_PLANE3 = 12291 	# /usr/include/GL/gl.h:320
GL_CLIP_PLANE4 = 12292 	# /usr/include/GL/gl.h:321
GL_CLIP_PLANE5 = 12293 	# /usr/include/GL/gl.h:322
GL_ACCUM_RED_BITS = 3416 	# /usr/include/GL/gl.h:325
GL_ACCUM_GREEN_BITS = 3417 	# /usr/include/GL/gl.h:326
GL_ACCUM_BLUE_BITS = 3418 	# /usr/include/GL/gl.h:327
GL_ACCUM_ALPHA_BITS = 3419 	# /usr/include/GL/gl.h:328
GL_ACCUM_CLEAR_VALUE = 2944 	# /usr/include/GL/gl.h:329
GL_ACCUM = 256 	# /usr/include/GL/gl.h:330
GL_ADD = 260 	# /usr/include/GL/gl.h:331
GL_LOAD = 257 	# /usr/include/GL/gl.h:332
GL_MULT = 259 	# /usr/include/GL/gl.h:333
GL_RETURN = 258 	# /usr/include/GL/gl.h:334
GL_ALPHA_TEST = 3008 	# /usr/include/GL/gl.h:337
GL_ALPHA_TEST_REF = 3010 	# /usr/include/GL/gl.h:338
GL_ALPHA_TEST_FUNC = 3009 	# /usr/include/GL/gl.h:339
GL_BLEND = 3042 	# /usr/include/GL/gl.h:342
GL_BLEND_SRC = 3041 	# /usr/include/GL/gl.h:343
GL_BLEND_DST = 3040 	# /usr/include/GL/gl.h:344
GL_ZERO = 0 	# /usr/include/GL/gl.h:345
GL_ONE = 1 	# /usr/include/GL/gl.h:346
GL_SRC_COLOR = 768 	# /usr/include/GL/gl.h:347
GL_ONE_MINUS_SRC_COLOR = 769 	# /usr/include/GL/gl.h:348
GL_SRC_ALPHA = 770 	# /usr/include/GL/gl.h:349
GL_ONE_MINUS_SRC_ALPHA = 771 	# /usr/include/GL/gl.h:350
GL_DST_ALPHA = 772 	# /usr/include/GL/gl.h:351
GL_ONE_MINUS_DST_ALPHA = 773 	# /usr/include/GL/gl.h:352
GL_DST_COLOR = 774 	# /usr/include/GL/gl.h:353
GL_ONE_MINUS_DST_COLOR = 775 	# /usr/include/GL/gl.h:354
GL_SRC_ALPHA_SATURATE = 776 	# /usr/include/GL/gl.h:355
GL_FEEDBACK = 7169 	# /usr/include/GL/gl.h:358
GL_RENDER = 7168 	# /usr/include/GL/gl.h:359
GL_SELECT = 7170 	# /usr/include/GL/gl.h:360
GL_2D = 1536 	# /usr/include/GL/gl.h:363
GL_3D = 1537 	# /usr/include/GL/gl.h:364
GL_3D_COLOR = 1538 	# /usr/include/GL/gl.h:365
GL_3D_COLOR_TEXTURE = 1539 	# /usr/include/GL/gl.h:366
GL_4D_COLOR_TEXTURE = 1540 	# /usr/include/GL/gl.h:367
GL_POINT_TOKEN = 1793 	# /usr/include/GL/gl.h:368
GL_LINE_TOKEN = 1794 	# /usr/include/GL/gl.h:369
GL_LINE_RESET_TOKEN = 1799 	# /usr/include/GL/gl.h:370
GL_POLYGON_TOKEN = 1795 	# /usr/include/GL/gl.h:371
GL_BITMAP_TOKEN = 1796 	# /usr/include/GL/gl.h:372
GL_DRAW_PIXEL_TOKEN = 1797 	# /usr/include/GL/gl.h:373
GL_COPY_PIXEL_TOKEN = 1798 	# /usr/include/GL/gl.h:374
GL_PASS_THROUGH_TOKEN = 1792 	# /usr/include/GL/gl.h:375
GL_FEEDBACK_BUFFER_POINTER = 3568 	# /usr/include/GL/gl.h:376
GL_FEEDBACK_BUFFER_SIZE = 3569 	# /usr/include/GL/gl.h:377
GL_FEEDBACK_BUFFER_TYPE = 3570 	# /usr/include/GL/gl.h:378
GL_SELECTION_BUFFER_POINTER = 3571 	# /usr/include/GL/gl.h:381
GL_SELECTION_BUFFER_SIZE = 3572 	# /usr/include/GL/gl.h:382
GL_FOG = 2912 	# /usr/include/GL/gl.h:385
GL_FOG_MODE = 2917 	# /usr/include/GL/gl.h:386
GL_FOG_DENSITY = 2914 	# /usr/include/GL/gl.h:387
GL_FOG_COLOR = 2918 	# /usr/include/GL/gl.h:388
GL_FOG_INDEX = 2913 	# /usr/include/GL/gl.h:389
GL_FOG_START = 2915 	# /usr/include/GL/gl.h:390
GL_FOG_END = 2916 	# /usr/include/GL/gl.h:391
GL_LINEAR = 9729 	# /usr/include/GL/gl.h:392
GL_EXP = 2048 	# /usr/include/GL/gl.h:393
GL_EXP2 = 2049 	# /usr/include/GL/gl.h:394
GL_LOGIC_OP = 3057 	# /usr/include/GL/gl.h:397
GL_INDEX_LOGIC_OP = 3057 	# /usr/include/GL/gl.h:398
GL_COLOR_LOGIC_OP = 3058 	# /usr/include/GL/gl.h:399
GL_LOGIC_OP_MODE = 3056 	# /usr/include/GL/gl.h:400
GL_CLEAR = 5376 	# /usr/include/GL/gl.h:401
GL_SET = 5391 	# /usr/include/GL/gl.h:402
GL_COPY = 5379 	# /usr/include/GL/gl.h:403
GL_COPY_INVERTED = 5388 	# /usr/include/GL/gl.h:404
GL_NOOP = 5381 	# /usr/include/GL/gl.h:405
GL_INVERT = 5386 	# /usr/include/GL/gl.h:406
GL_AND = 5377 	# /usr/include/GL/gl.h:407
GL_NAND = 5390 	# /usr/include/GL/gl.h:408
GL_OR = 5383 	# /usr/include/GL/gl.h:409
GL_NOR = 5384 	# /usr/include/GL/gl.h:410
GL_XOR = 5382 	# /usr/include/GL/gl.h:411
GL_EQUIV = 5385 	# /usr/include/GL/gl.h:412
GL_AND_REVERSE = 5378 	# /usr/include/GL/gl.h:413
GL_AND_INVERTED = 5380 	# /usr/include/GL/gl.h:414
GL_OR_REVERSE = 5387 	# /usr/include/GL/gl.h:415
GL_OR_INVERTED = 5389 	# /usr/include/GL/gl.h:416
GL_STENCIL_BITS = 3415 	# /usr/include/GL/gl.h:419
GL_STENCIL_TEST = 2960 	# /usr/include/GL/gl.h:420
GL_STENCIL_CLEAR_VALUE = 2961 	# /usr/include/GL/gl.h:421
GL_STENCIL_FUNC = 2962 	# /usr/include/GL/gl.h:422
GL_STENCIL_VALUE_MASK = 2963 	# /usr/include/GL/gl.h:423
GL_STENCIL_FAIL = 2964 	# /usr/include/GL/gl.h:424
GL_STENCIL_PASS_DEPTH_FAIL = 2965 	# /usr/include/GL/gl.h:425
GL_STENCIL_PASS_DEPTH_PASS = 2966 	# /usr/include/GL/gl.h:426
GL_STENCIL_REF = 2967 	# /usr/include/GL/gl.h:427
GL_STENCIL_WRITEMASK = 2968 	# /usr/include/GL/gl.h:428
GL_STENCIL_INDEX = 6401 	# /usr/include/GL/gl.h:429
GL_KEEP = 7680 	# /usr/include/GL/gl.h:430
GL_REPLACE = 7681 	# /usr/include/GL/gl.h:431
GL_INCR = 7682 	# /usr/include/GL/gl.h:432
GL_DECR = 7683 	# /usr/include/GL/gl.h:433
GL_NONE = 0 	# /usr/include/GL/gl.h:436
GL_LEFT = 1030 	# /usr/include/GL/gl.h:437
GL_RIGHT = 1031 	# /usr/include/GL/gl.h:438
GL_FRONT_LEFT = 1024 	# /usr/include/GL/gl.h:442
GL_FRONT_RIGHT = 1025 	# /usr/include/GL/gl.h:443
GL_BACK_LEFT = 1026 	# /usr/include/GL/gl.h:444
GL_BACK_RIGHT = 1027 	# /usr/include/GL/gl.h:445
GL_AUX0 = 1033 	# /usr/include/GL/gl.h:446
GL_AUX1 = 1034 	# /usr/include/GL/gl.h:447
GL_AUX2 = 1035 	# /usr/include/GL/gl.h:448
GL_AUX3 = 1036 	# /usr/include/GL/gl.h:449
GL_COLOR_INDEX = 6400 	# /usr/include/GL/gl.h:450
GL_RED = 6403 	# /usr/include/GL/gl.h:451
GL_GREEN = 6404 	# /usr/include/GL/gl.h:452
GL_BLUE = 6405 	# /usr/include/GL/gl.h:453
GL_ALPHA = 6406 	# /usr/include/GL/gl.h:454
GL_LUMINANCE = 6409 	# /usr/include/GL/gl.h:455
GL_LUMINANCE_ALPHA = 6410 	# /usr/include/GL/gl.h:456
GL_ALPHA_BITS = 3413 	# /usr/include/GL/gl.h:457
GL_RED_BITS = 3410 	# /usr/include/GL/gl.h:458
GL_GREEN_BITS = 3411 	# /usr/include/GL/gl.h:459
GL_BLUE_BITS = 3412 	# /usr/include/GL/gl.h:460
GL_INDEX_BITS = 3409 	# /usr/include/GL/gl.h:461
GL_SUBPIXEL_BITS = 3408 	# /usr/include/GL/gl.h:462
GL_AUX_BUFFERS = 3072 	# /usr/include/GL/gl.h:463
GL_READ_BUFFER = 3074 	# /usr/include/GL/gl.h:464
GL_DRAW_BUFFER = 3073 	# /usr/include/GL/gl.h:465
GL_DOUBLEBUFFER = 3122 	# /usr/include/GL/gl.h:466
GL_STEREO = 3123 	# /usr/include/GL/gl.h:467
GL_BITMAP = 6656 	# /usr/include/GL/gl.h:468
GL_COLOR = 6144 	# /usr/include/GL/gl.h:469
GL_DEPTH = 6145 	# /usr/include/GL/gl.h:470
GL_STENCIL = 6146 	# /usr/include/GL/gl.h:471
GL_DITHER = 3024 	# /usr/include/GL/gl.h:472
GL_RGB = 6407 	# /usr/include/GL/gl.h:473
GL_RGBA = 6408 	# /usr/include/GL/gl.h:474
GL_MAX_LIST_NESTING = 2865 	# /usr/include/GL/gl.h:477
GL_MAX_EVAL_ORDER = 3376 	# /usr/include/GL/gl.h:478
GL_MAX_LIGHTS = 3377 	# /usr/include/GL/gl.h:479
GL_MAX_CLIP_PLANES = 3378 	# /usr/include/GL/gl.h:480
GL_MAX_TEXTURE_SIZE = 3379 	# /usr/include/GL/gl.h:481
GL_MAX_PIXEL_MAP_TABLE = 3380 	# /usr/include/GL/gl.h:482
GL_MAX_ATTRIB_STACK_DEPTH = 3381 	# /usr/include/GL/gl.h:483
GL_MAX_MODELVIEW_STACK_DEPTH = 3382 	# /usr/include/GL/gl.h:484
GL_MAX_NAME_STACK_DEPTH = 3383 	# /usr/include/GL/gl.h:485
GL_MAX_PROJECTION_STACK_DEPTH = 3384 	# /usr/include/GL/gl.h:486
GL_MAX_TEXTURE_STACK_DEPTH = 3385 	# /usr/include/GL/gl.h:487
GL_MAX_VIEWPORT_DIMS = 3386 	# /usr/include/GL/gl.h:488
GL_MAX_CLIENT_ATTRIB_STACK_DEPTH = 3387 	# /usr/include/GL/gl.h:489
GL_ATTRIB_STACK_DEPTH = 2992 	# /usr/include/GL/gl.h:492
GL_CLIENT_ATTRIB_STACK_DEPTH = 2993 	# /usr/include/GL/gl.h:493
GL_COLOR_CLEAR_VALUE = 3106 	# /usr/include/GL/gl.h:494
GL_COLOR_WRITEMASK = 3107 	# /usr/include/GL/gl.h:495
GL_CURRENT_INDEX = 2817 	# /usr/include/GL/gl.h:496
GL_CURRENT_COLOR = 2816 	# /usr/include/GL/gl.h:497
GL_CURRENT_NORMAL = 2818 	# /usr/include/GL/gl.h:498
GL_CURRENT_RASTER_COLOR = 2820 	# /usr/include/GL/gl.h:499
GL_CURRENT_RASTER_DISTANCE = 2825 	# /usr/include/GL/gl.h:500
GL_CURRENT_RASTER_INDEX = 2821 	# /usr/include/GL/gl.h:501
GL_CURRENT_RASTER_POSITION = 2823 	# /usr/include/GL/gl.h:502
GL_CURRENT_RASTER_TEXTURE_COORDS = 2822 	# /usr/include/GL/gl.h:503
GL_CURRENT_RASTER_POSITION_VALID = 2824 	# /usr/include/GL/gl.h:504
GL_CURRENT_TEXTURE_COORDS = 2819 	# /usr/include/GL/gl.h:505
GL_INDEX_CLEAR_VALUE = 3104 	# /usr/include/GL/gl.h:506
GL_INDEX_MODE = 3120 	# /usr/include/GL/gl.h:507
GL_INDEX_WRITEMASK = 3105 	# /usr/include/GL/gl.h:508
GL_MODELVIEW_MATRIX = 2982 	# /usr/include/GL/gl.h:509
GL_MODELVIEW_STACK_DEPTH = 2979 	# /usr/include/GL/gl.h:510
GL_NAME_STACK_DEPTH = 3440 	# /usr/include/GL/gl.h:511
GL_PROJECTION_MATRIX = 2983 	# /usr/include/GL/gl.h:512
GL_PROJECTION_STACK_DEPTH = 2980 	# /usr/include/GL/gl.h:513
GL_RENDER_MODE = 3136 	# /usr/include/GL/gl.h:514
GL_RGBA_MODE = 3121 	# /usr/include/GL/gl.h:515
GL_TEXTURE_MATRIX = 2984 	# /usr/include/GL/gl.h:516
GL_TEXTURE_STACK_DEPTH = 2981 	# /usr/include/GL/gl.h:517
GL_VIEWPORT = 2978 	# /usr/include/GL/gl.h:518
GL_AUTO_NORMAL = 3456 	# /usr/include/GL/gl.h:521
GL_MAP1_COLOR_4 = 3472 	# /usr/include/GL/gl.h:522
GL_MAP1_INDEX = 3473 	# /usr/include/GL/gl.h:523
GL_MAP1_NORMAL = 3474 	# /usr/include/GL/gl.h:524
GL_MAP1_TEXTURE_COORD_1 = 3475 	# /usr/include/GL/gl.h:525
GL_MAP1_TEXTURE_COORD_2 = 3476 	# /usr/include/GL/gl.h:526
GL_MAP1_TEXTURE_COORD_3 = 3477 	# /usr/include/GL/gl.h:527
GL_MAP1_TEXTURE_COORD_4 = 3478 	# /usr/include/GL/gl.h:528
GL_MAP1_VERTEX_3 = 3479 	# /usr/include/GL/gl.h:529
GL_MAP1_VERTEX_4 = 3480 	# /usr/include/GL/gl.h:530
GL_MAP2_COLOR_4 = 3504 	# /usr/include/GL/gl.h:531
GL_MAP2_INDEX = 3505 	# /usr/include/GL/gl.h:532
GL_MAP2_NORMAL = 3506 	# /usr/include/GL/gl.h:533
GL_MAP2_TEXTURE_COORD_1 = 3507 	# /usr/include/GL/gl.h:534
GL_MAP2_TEXTURE_COORD_2 = 3508 	# /usr/include/GL/gl.h:535
GL_MAP2_TEXTURE_COORD_3 = 3509 	# /usr/include/GL/gl.h:536
GL_MAP2_TEXTURE_COORD_4 = 3510 	# /usr/include/GL/gl.h:537
GL_MAP2_VERTEX_3 = 3511 	# /usr/include/GL/gl.h:538
GL_MAP2_VERTEX_4 = 3512 	# /usr/include/GL/gl.h:539
GL_MAP1_GRID_DOMAIN = 3536 	# /usr/include/GL/gl.h:540
GL_MAP1_GRID_SEGMENTS = 3537 	# /usr/include/GL/gl.h:541
GL_MAP2_GRID_DOMAIN = 3538 	# /usr/include/GL/gl.h:542
GL_MAP2_GRID_SEGMENTS = 3539 	# /usr/include/GL/gl.h:543
GL_COEFF = 2560 	# /usr/include/GL/gl.h:544
GL_ORDER = 2561 	# /usr/include/GL/gl.h:545
GL_DOMAIN = 2562 	# /usr/include/GL/gl.h:546
GL_PERSPECTIVE_CORRECTION_HINT = 3152 	# /usr/include/GL/gl.h:549
GL_POINT_SMOOTH_HINT = 3153 	# /usr/include/GL/gl.h:550
GL_LINE_SMOOTH_HINT = 3154 	# /usr/include/GL/gl.h:551
GL_POLYGON_SMOOTH_HINT = 3155 	# /usr/include/GL/gl.h:552
GL_FOG_HINT = 3156 	# /usr/include/GL/gl.h:553
GL_DONT_CARE = 4352 	# /usr/include/GL/gl.h:554
GL_FASTEST = 4353 	# /usr/include/GL/gl.h:555
GL_NICEST = 4354 	# /usr/include/GL/gl.h:556
GL_SCISSOR_BOX = 3088 	# /usr/include/GL/gl.h:559
GL_SCISSOR_TEST = 3089 	# /usr/include/GL/gl.h:560
GL_MAP_COLOR = 3344 	# /usr/include/GL/gl.h:563
GL_MAP_STENCIL = 3345 	# /usr/include/GL/gl.h:564
GL_INDEX_SHIFT = 3346 	# /usr/include/GL/gl.h:565
GL_INDEX_OFFSET = 3347 	# /usr/include/GL/gl.h:566
GL_RED_SCALE = 3348 	# /usr/include/GL/gl.h:567
GL_RED_BIAS = 3349 	# /usr/include/GL/gl.h:568
GL_GREEN_SCALE = 3352 	# /usr/include/GL/gl.h:569
GL_GREEN_BIAS = 3353 	# /usr/include/GL/gl.h:570
GL_BLUE_SCALE = 3354 	# /usr/include/GL/gl.h:571
GL_BLUE_BIAS = 3355 	# /usr/include/GL/gl.h:572
GL_ALPHA_SCALE = 3356 	# /usr/include/GL/gl.h:573
GL_ALPHA_BIAS = 3357 	# /usr/include/GL/gl.h:574
GL_DEPTH_SCALE = 3358 	# /usr/include/GL/gl.h:575
GL_DEPTH_BIAS = 3359 	# /usr/include/GL/gl.h:576
GL_PIXEL_MAP_S_TO_S_SIZE = 3249 	# /usr/include/GL/gl.h:577
GL_PIXEL_MAP_I_TO_I_SIZE = 3248 	# /usr/include/GL/gl.h:578
GL_PIXEL_MAP_I_TO_R_SIZE = 3250 	# /usr/include/GL/gl.h:579
GL_PIXEL_MAP_I_TO_G_SIZE = 3251 	# /usr/include/GL/gl.h:580
GL_PIXEL_MAP_I_TO_B_SIZE = 3252 	# /usr/include/GL/gl.h:581
GL_PIXEL_MAP_I_TO_A_SIZE = 3253 	# /usr/include/GL/gl.h:582
GL_PIXEL_MAP_R_TO_R_SIZE = 3254 	# /usr/include/GL/gl.h:583
GL_PIXEL_MAP_G_TO_G_SIZE = 3255 	# /usr/include/GL/gl.h:584
GL_PIXEL_MAP_B_TO_B_SIZE = 3256 	# /usr/include/GL/gl.h:585
GL_PIXEL_MAP_A_TO_A_SIZE = 3257 	# /usr/include/GL/gl.h:586
GL_PIXEL_MAP_S_TO_S = 3185 	# /usr/include/GL/gl.h:587
GL_PIXEL_MAP_I_TO_I = 3184 	# /usr/include/GL/gl.h:588
GL_PIXEL_MAP_I_TO_R = 3186 	# /usr/include/GL/gl.h:589
GL_PIXEL_MAP_I_TO_G = 3187 	# /usr/include/GL/gl.h:590
GL_PIXEL_MAP_I_TO_B = 3188 	# /usr/include/GL/gl.h:591
GL_PIXEL_MAP_I_TO_A = 3189 	# /usr/include/GL/gl.h:592
GL_PIXEL_MAP_R_TO_R = 3190 	# /usr/include/GL/gl.h:593
GL_PIXEL_MAP_G_TO_G = 3191 	# /usr/include/GL/gl.h:594
GL_PIXEL_MAP_B_TO_B = 3192 	# /usr/include/GL/gl.h:595
GL_PIXEL_MAP_A_TO_A = 3193 	# /usr/include/GL/gl.h:596
GL_PACK_ALIGNMENT = 3333 	# /usr/include/GL/gl.h:597
GL_PACK_LSB_FIRST = 3329 	# /usr/include/GL/gl.h:598
GL_PACK_ROW_LENGTH = 3330 	# /usr/include/GL/gl.h:599
GL_PACK_SKIP_PIXELS = 3332 	# /usr/include/GL/gl.h:600
GL_PACK_SKIP_ROWS = 3331 	# /usr/include/GL/gl.h:601
GL_PACK_SWAP_BYTES = 3328 	# /usr/include/GL/gl.h:602
GL_UNPACK_ALIGNMENT = 3317 	# /usr/include/GL/gl.h:603
GL_UNPACK_LSB_FIRST = 3313 	# /usr/include/GL/gl.h:604
GL_UNPACK_ROW_LENGTH = 3314 	# /usr/include/GL/gl.h:605
GL_UNPACK_SKIP_PIXELS = 3316 	# /usr/include/GL/gl.h:606
GL_UNPACK_SKIP_ROWS = 3315 	# /usr/include/GL/gl.h:607
GL_UNPACK_SWAP_BYTES = 3312 	# /usr/include/GL/gl.h:608
GL_ZOOM_X = 3350 	# /usr/include/GL/gl.h:609
GL_ZOOM_Y = 3351 	# /usr/include/GL/gl.h:610
GL_TEXTURE_ENV = 8960 	# /usr/include/GL/gl.h:613
GL_TEXTURE_ENV_MODE = 8704 	# /usr/include/GL/gl.h:614
GL_TEXTURE_1D = 3552 	# /usr/include/GL/gl.h:615
GL_TEXTURE_2D = 3553 	# /usr/include/GL/gl.h:616
GL_TEXTURE_WRAP_S = 10242 	# /usr/include/GL/gl.h:617
GL_TEXTURE_WRAP_T = 10243 	# /usr/include/GL/gl.h:618
GL_TEXTURE_MAG_FILTER = 10240 	# /usr/include/GL/gl.h:619
GL_TEXTURE_MIN_FILTER = 10241 	# /usr/include/GL/gl.h:620
GL_TEXTURE_ENV_COLOR = 8705 	# /usr/include/GL/gl.h:621
GL_TEXTURE_GEN_S = 3168 	# /usr/include/GL/gl.h:622
GL_TEXTURE_GEN_T = 3169 	# /usr/include/GL/gl.h:623
GL_TEXTURE_GEN_R = 3170 	# /usr/include/GL/gl.h:624
GL_TEXTURE_GEN_Q = 3171 	# /usr/include/GL/gl.h:625
GL_TEXTURE_GEN_MODE = 9472 	# /usr/include/GL/gl.h:626
GL_TEXTURE_BORDER_COLOR = 4100 	# /usr/include/GL/gl.h:627
GL_TEXTURE_WIDTH = 4096 	# /usr/include/GL/gl.h:628
GL_TEXTURE_HEIGHT = 4097 	# /usr/include/GL/gl.h:629
GL_TEXTURE_BORDER = 4101 	# /usr/include/GL/gl.h:630
GL_TEXTURE_COMPONENTS = 4099 	# /usr/include/GL/gl.h:631
GL_TEXTURE_RED_SIZE = 32860 	# /usr/include/GL/gl.h:632
GL_TEXTURE_GREEN_SIZE = 32861 	# /usr/include/GL/gl.h:633
GL_TEXTURE_BLUE_SIZE = 32862 	# /usr/include/GL/gl.h:634
GL_TEXTURE_ALPHA_SIZE = 32863 	# /usr/include/GL/gl.h:635
GL_TEXTURE_LUMINANCE_SIZE = 32864 	# /usr/include/GL/gl.h:636
GL_TEXTURE_INTENSITY_SIZE = 32865 	# /usr/include/GL/gl.h:637
GL_NEAREST_MIPMAP_NEAREST = 9984 	# /usr/include/GL/gl.h:638
GL_NEAREST_MIPMAP_LINEAR = 9986 	# /usr/include/GL/gl.h:639
GL_LINEAR_MIPMAP_NEAREST = 9985 	# /usr/include/GL/gl.h:640
GL_LINEAR_MIPMAP_LINEAR = 9987 	# /usr/include/GL/gl.h:641
GL_OBJECT_LINEAR = 9217 	# /usr/include/GL/gl.h:642
GL_OBJECT_PLANE = 9473 	# /usr/include/GL/gl.h:643
GL_EYE_LINEAR = 9216 	# /usr/include/GL/gl.h:644
GL_EYE_PLANE = 9474 	# /usr/include/GL/gl.h:645
GL_SPHERE_MAP = 9218 	# /usr/include/GL/gl.h:646
GL_DECAL = 8449 	# /usr/include/GL/gl.h:647
GL_MODULATE = 8448 	# /usr/include/GL/gl.h:648
GL_NEAREST = 9728 	# /usr/include/GL/gl.h:649
GL_REPEAT = 10497 	# /usr/include/GL/gl.h:650
GL_CLAMP = 10496 	# /usr/include/GL/gl.h:651
GL_S = 8192 	# /usr/include/GL/gl.h:652
GL_T = 8193 	# /usr/include/GL/gl.h:653
GL_R = 8194 	# /usr/include/GL/gl.h:654
GL_Q = 8195 	# /usr/include/GL/gl.h:655
GL_VENDOR = 7936 	# /usr/include/GL/gl.h:658
GL_RENDERER = 7937 	# /usr/include/GL/gl.h:659
GL_VERSION = 7938 	# /usr/include/GL/gl.h:660
GL_EXTENSIONS = 7939 	# /usr/include/GL/gl.h:661
GL_NO_ERROR = 0 	# /usr/include/GL/gl.h:664
GL_INVALID_ENUM = 1280 	# /usr/include/GL/gl.h:665
GL_INVALID_VALUE = 1281 	# /usr/include/GL/gl.h:666
GL_INVALID_OPERATION = 1282 	# /usr/include/GL/gl.h:667
GL_STACK_OVERFLOW = 1283 	# /usr/include/GL/gl.h:668
GL_STACK_UNDERFLOW = 1284 	# /usr/include/GL/gl.h:669
GL_OUT_OF_MEMORY = 1285 	# /usr/include/GL/gl.h:670
GL_CURRENT_BIT = 1 	# /usr/include/GL/gl.h:673
GL_POINT_BIT = 2 	# /usr/include/GL/gl.h:674
GL_LINE_BIT = 4 	# /usr/include/GL/gl.h:675
GL_POLYGON_BIT = 8 	# /usr/include/GL/gl.h:676
GL_POLYGON_STIPPLE_BIT = 16 	# /usr/include/GL/gl.h:677
GL_PIXEL_MODE_BIT = 32 	# /usr/include/GL/gl.h:678
GL_LIGHTING_BIT = 64 	# /usr/include/GL/gl.h:679
GL_FOG_BIT = 128 	# /usr/include/GL/gl.h:680
GL_DEPTH_BUFFER_BIT = 256 	# /usr/include/GL/gl.h:681
GL_ACCUM_BUFFER_BIT = 512 	# /usr/include/GL/gl.h:682
GL_STENCIL_BUFFER_BIT = 1024 	# /usr/include/GL/gl.h:683
GL_VIEWPORT_BIT = 2048 	# /usr/include/GL/gl.h:684
GL_TRANSFORM_BIT = 4096 	# /usr/include/GL/gl.h:685
GL_ENABLE_BIT = 8192 	# /usr/include/GL/gl.h:686
GL_COLOR_BUFFER_BIT = 16384 	# /usr/include/GL/gl.h:687
GL_HINT_BIT = 32768 	# /usr/include/GL/gl.h:688
GL_EVAL_BIT = 65536 	# /usr/include/GL/gl.h:689
GL_LIST_BIT = 131072 	# /usr/include/GL/gl.h:690
GL_TEXTURE_BIT = 262144 	# /usr/include/GL/gl.h:691
GL_SCISSOR_BIT = 524288 	# /usr/include/GL/gl.h:692
GL_ALL_ATTRIB_BITS = 4294967295 	# /usr/include/GL/gl.h:693
GL_PROXY_TEXTURE_1D = 32867 	# /usr/include/GL/gl.h:697
GL_PROXY_TEXTURE_2D = 32868 	# /usr/include/GL/gl.h:698
GL_TEXTURE_PRIORITY = 32870 	# /usr/include/GL/gl.h:699
GL_TEXTURE_RESIDENT = 32871 	# /usr/include/GL/gl.h:700
GL_TEXTURE_BINDING_1D = 32872 	# /usr/include/GL/gl.h:701
GL_TEXTURE_BINDING_2D = 32873 	# /usr/include/GL/gl.h:702
GL_TEXTURE_INTERNAL_FORMAT = 4099 	# /usr/include/GL/gl.h:703
GL_ALPHA4 = 32827 	# /usr/include/GL/gl.h:704
GL_ALPHA8 = 32828 	# /usr/include/GL/gl.h:705
GL_ALPHA12 = 32829 	# /usr/include/GL/gl.h:706
GL_ALPHA16 = 32830 	# /usr/include/GL/gl.h:707
GL_LUMINANCE4 = 32831 	# /usr/include/GL/gl.h:708
GL_LUMINANCE8 = 32832 	# /usr/include/GL/gl.h:709
GL_LUMINANCE12 = 32833 	# /usr/include/GL/gl.h:710
GL_LUMINANCE16 = 32834 	# /usr/include/GL/gl.h:711
GL_LUMINANCE4_ALPHA4 = 32835 	# /usr/include/GL/gl.h:712
GL_LUMINANCE6_ALPHA2 = 32836 	# /usr/include/GL/gl.h:713
GL_LUMINANCE8_ALPHA8 = 32837 	# /usr/include/GL/gl.h:714
GL_LUMINANCE12_ALPHA4 = 32838 	# /usr/include/GL/gl.h:715
GL_LUMINANCE12_ALPHA12 = 32839 	# /usr/include/GL/gl.h:716
GL_LUMINANCE16_ALPHA16 = 32840 	# /usr/include/GL/gl.h:717
GL_INTENSITY = 32841 	# /usr/include/GL/gl.h:718
GL_INTENSITY4 = 32842 	# /usr/include/GL/gl.h:719
GL_INTENSITY8 = 32843 	# /usr/include/GL/gl.h:720
GL_INTENSITY12 = 32844 	# /usr/include/GL/gl.h:721
GL_INTENSITY16 = 32845 	# /usr/include/GL/gl.h:722
GL_R3_G3_B2 = 10768 	# /usr/include/GL/gl.h:723
GL_RGB4 = 32847 	# /usr/include/GL/gl.h:724
GL_RGB5 = 32848 	# /usr/include/GL/gl.h:725
GL_RGB8 = 32849 	# /usr/include/GL/gl.h:726
GL_RGB10 = 32850 	# /usr/include/GL/gl.h:727
GL_RGB12 = 32851 	# /usr/include/GL/gl.h:728
GL_RGB16 = 32852 	# /usr/include/GL/gl.h:729
GL_RGBA2 = 32853 	# /usr/include/GL/gl.h:730
GL_RGBA4 = 32854 	# /usr/include/GL/gl.h:731
GL_RGB5_A1 = 32855 	# /usr/include/GL/gl.h:732
GL_RGBA8 = 32856 	# /usr/include/GL/gl.h:733
GL_RGB10_A2 = 32857 	# /usr/include/GL/gl.h:734
GL_RGBA12 = 32858 	# /usr/include/GL/gl.h:735
GL_RGBA16 = 32859 	# /usr/include/GL/gl.h:736
GL_CLIENT_PIXEL_STORE_BIT = 1 	# /usr/include/GL/gl.h:737
GL_CLIENT_VERTEX_ARRAY_BIT = 2 	# /usr/include/GL/gl.h:738
GL_ALL_CLIENT_ATTRIB_BITS = 4294967295 	# /usr/include/GL/gl.h:739
GL_CLIENT_ALL_ATTRIB_BITS = 4294967295 	# /usr/include/GL/gl.h:740
# /usr/include/GL/gl.h:748
glClearIndex = _link_function('glClearIndex', None, [GLfloat], None)

# /usr/include/GL/gl.h:750
glClearColor = _link_function('glClearColor', None, [GLclampf, GLclampf, GLclampf, GLclampf], None)

# /usr/include/GL/gl.h:752
glClear = _link_function('glClear', None, [GLbitfield], None)

# /usr/include/GL/gl.h:754
glIndexMask = _link_function('glIndexMask', None, [GLuint], None)

# /usr/include/GL/gl.h:756
glColorMask = _link_function('glColorMask', None, [GLboolean, GLboolean, GLboolean, GLboolean], None)

# /usr/include/GL/gl.h:758
glAlphaFunc = _link_function('glAlphaFunc', None, [GLenum, GLclampf], None)

# /usr/include/GL/gl.h:760
glBlendFunc = _link_function('glBlendFunc', None, [GLenum, GLenum], None)

# /usr/include/GL/gl.h:762
glLogicOp = _link_function('glLogicOp', None, [GLenum], None)

# /usr/include/GL/gl.h:764
glCullFace = _link_function('glCullFace', None, [GLenum], None)

# /usr/include/GL/gl.h:766
glFrontFace = _link_function('glFrontFace', None, [GLenum], None)

# /usr/include/GL/gl.h:768
glPointSize = _link_function('glPointSize', None, [GLfloat], None)

# /usr/include/GL/gl.h:770
glLineWidth = _link_function('glLineWidth', None, [GLfloat], None)

# /usr/include/GL/gl.h:772
glLineStipple = _link_function('glLineStipple', None, [GLint, GLushort], None)

# /usr/include/GL/gl.h:774
glPolygonMode = _link_function('glPolygonMode', None, [GLenum, GLenum], None)

# /usr/include/GL/gl.h:776
glPolygonOffset = _link_function('glPolygonOffset', None, [GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:778
glPolygonStipple = _link_function('glPolygonStipple', None, [POINTER(GLubyte)], None)

# /usr/include/GL/gl.h:780
glGetPolygonStipple = _link_function('glGetPolygonStipple', None, [POINTER(GLubyte)], None)

# /usr/include/GL/gl.h:782
glEdgeFlag = _link_function('glEdgeFlag', None, [GLboolean], None)

# /usr/include/GL/gl.h:784
glEdgeFlagv = _link_function('glEdgeFlagv', None, [POINTER(GLboolean)], None)

# /usr/include/GL/gl.h:786
glScissor = _link_function('glScissor', None, [GLint, GLint, GLsizei, GLsizei], None)

# /usr/include/GL/gl.h:788
glClipPlane = _link_function('glClipPlane', None, [GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:790
glGetClipPlane = _link_function('glGetClipPlane', None, [GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:792
glDrawBuffer = _link_function('glDrawBuffer', None, [GLenum], None)

# /usr/include/GL/gl.h:794
glReadBuffer = _link_function('glReadBuffer', None, [GLenum], None)

# /usr/include/GL/gl.h:796
glEnable = _link_function('glEnable', None, [GLenum], None)

# /usr/include/GL/gl.h:798
glDisable = _link_function('glDisable', None, [GLenum], None)

# /usr/include/GL/gl.h:800
glIsEnabled = _link_function('glIsEnabled', GLboolean, [GLenum], None)

# /usr/include/GL/gl.h:803
glEnableClientState = _link_function('glEnableClientState', None, [GLenum], None)

# /usr/include/GL/gl.h:805
glDisableClientState = _link_function('glDisableClientState', None, [GLenum], None)

# /usr/include/GL/gl.h:808
glGetBooleanv = _link_function('glGetBooleanv', None, [GLenum, POINTER(GLboolean)], None)

# /usr/include/GL/gl.h:810
glGetDoublev = _link_function('glGetDoublev', None, [GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:812
glGetFloatv = _link_function('glGetFloatv', None, [GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:814
glGetIntegerv = _link_function('glGetIntegerv', None, [GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:817
glPushAttrib = _link_function('glPushAttrib', None, [GLbitfield], None)

# /usr/include/GL/gl.h:819
glPopAttrib = _link_function('glPopAttrib', None, [], None)

# /usr/include/GL/gl.h:822
glPushClientAttrib = _link_function('glPushClientAttrib', None, [GLbitfield], None)

# /usr/include/GL/gl.h:824
glPopClientAttrib = _link_function('glPopClientAttrib', None, [], None)

# /usr/include/GL/gl.h:827
glRenderMode = _link_function('glRenderMode', GLint, [GLenum], None)

# /usr/include/GL/gl.h:829
glGetError = _link_function('glGetError', GLenum, [], None)

# /usr/include/GL/gl.h:831
glGetString = _link_function('glGetString', POINTER(GLubyte), [GLenum], None)

# /usr/include/GL/gl.h:833
glFinish = _link_function('glFinish', None, [], None)

# /usr/include/GL/gl.h:835
glFlush = _link_function('glFlush', None, [], None)

# /usr/include/GL/gl.h:837
glHint = _link_function('glHint', None, [GLenum, GLenum], None)

# /usr/include/GL/gl.h:844
glClearDepth = _link_function('glClearDepth', None, [GLclampd], None)

# /usr/include/GL/gl.h:846
glDepthFunc = _link_function('glDepthFunc', None, [GLenum], None)

# /usr/include/GL/gl.h:848
glDepthMask = _link_function('glDepthMask', None, [GLboolean], None)

# /usr/include/GL/gl.h:850
glDepthRange = _link_function('glDepthRange', None, [GLclampd, GLclampd], None)

# /usr/include/GL/gl.h:857
glClearAccum = _link_function('glClearAccum', None, [GLfloat, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:859
glAccum = _link_function('glAccum', None, [GLenum, GLfloat], None)

# /usr/include/GL/gl.h:866
glMatrixMode = _link_function('glMatrixMode', None, [GLenum], None)

# /usr/include/GL/gl.h:868
glOrtho = _link_function('glOrtho', None, [GLdouble, GLdouble, GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:872
glFrustum = _link_function('glFrustum', None, [GLdouble, GLdouble, GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:876
glViewport = _link_function('glViewport', None, [GLint, GLint, GLsizei, GLsizei], None)

# /usr/include/GL/gl.h:879
glPushMatrix = _link_function('glPushMatrix', None, [], None)

# /usr/include/GL/gl.h:881
glPopMatrix = _link_function('glPopMatrix', None, [], None)

# /usr/include/GL/gl.h:883
glLoadIdentity = _link_function('glLoadIdentity', None, [], None)

# /usr/include/GL/gl.h:885
glLoadMatrixd = _link_function('glLoadMatrixd', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:886
glLoadMatrixf = _link_function('glLoadMatrixf', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:888
glMultMatrixd = _link_function('glMultMatrixd', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:889
glMultMatrixf = _link_function('glMultMatrixf', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:891
glRotated = _link_function('glRotated', None, [GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:893
glRotatef = _link_function('glRotatef', None, [GLfloat, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:896
glScaled = _link_function('glScaled', None, [GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:897
glScalef = _link_function('glScalef', None, [GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:899
glTranslated = _link_function('glTranslated', None, [GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:900
glTranslatef = _link_function('glTranslatef', None, [GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:907
glIsList = _link_function('glIsList', GLboolean, [GLuint], None)

# /usr/include/GL/gl.h:909
glDeleteLists = _link_function('glDeleteLists', None, [GLuint, GLsizei], None)

# /usr/include/GL/gl.h:911
glGenLists = _link_function('glGenLists', GLuint, [GLsizei], None)

# /usr/include/GL/gl.h:913
glNewList = _link_function('glNewList', None, [GLuint, GLenum], None)

# /usr/include/GL/gl.h:915
glEndList = _link_function('glEndList', None, [], None)

# /usr/include/GL/gl.h:917
glCallList = _link_function('glCallList', None, [GLuint], None)

# /usr/include/GL/gl.h:919
glCallLists = _link_function('glCallLists', None, [GLsizei, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:922
glListBase = _link_function('glListBase', None, [GLuint], None)

# /usr/include/GL/gl.h:929
glBegin = _link_function('glBegin', None, [GLenum], None)

# /usr/include/GL/gl.h:931
glEnd = _link_function('glEnd', None, [], None)

# /usr/include/GL/gl.h:934
glVertex2d = _link_function('glVertex2d', None, [GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:935
glVertex2f = _link_function('glVertex2f', None, [GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:936
glVertex2i = _link_function('glVertex2i', None, [GLint, GLint], None)

# /usr/include/GL/gl.h:937
glVertex2s = _link_function('glVertex2s', None, [GLshort, GLshort], None)

# /usr/include/GL/gl.h:939
glVertex3d = _link_function('glVertex3d', None, [GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:940
glVertex3f = _link_function('glVertex3f', None, [GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:941
glVertex3i = _link_function('glVertex3i', None, [GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:942
glVertex3s = _link_function('glVertex3s', None, [GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:944
glVertex4d = _link_function('glVertex4d', None, [GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:945
glVertex4f = _link_function('glVertex4f', None, [GLfloat, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:946
glVertex4i = _link_function('glVertex4i', None, [GLint, GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:947
glVertex4s = _link_function('glVertex4s', None, [GLshort, GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:949
glVertex2dv = _link_function('glVertex2dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:950
glVertex2fv = _link_function('glVertex2fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:951
glVertex2iv = _link_function('glVertex2iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:952
glVertex2sv = _link_function('glVertex2sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:954
glVertex3dv = _link_function('glVertex3dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:955
glVertex3fv = _link_function('glVertex3fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:956
glVertex3iv = _link_function('glVertex3iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:957
glVertex3sv = _link_function('glVertex3sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:959
glVertex4dv = _link_function('glVertex4dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:960
glVertex4fv = _link_function('glVertex4fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:961
glVertex4iv = _link_function('glVertex4iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:962
glVertex4sv = _link_function('glVertex4sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:965
glNormal3b = _link_function('glNormal3b', None, [GLbyte, GLbyte, GLbyte], None)

# /usr/include/GL/gl.h:966
glNormal3d = _link_function('glNormal3d', None, [GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:967
glNormal3f = _link_function('glNormal3f', None, [GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:968
glNormal3i = _link_function('glNormal3i', None, [GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:969
glNormal3s = _link_function('glNormal3s', None, [GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:971
glNormal3bv = _link_function('glNormal3bv', None, [POINTER(GLbyte)], None)

# /usr/include/GL/gl.h:972
glNormal3dv = _link_function('glNormal3dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:973
glNormal3fv = _link_function('glNormal3fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:974
glNormal3iv = _link_function('glNormal3iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:975
glNormal3sv = _link_function('glNormal3sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:978
glIndexd = _link_function('glIndexd', None, [GLdouble], None)

# /usr/include/GL/gl.h:979
glIndexf = _link_function('glIndexf', None, [GLfloat], None)

# /usr/include/GL/gl.h:980
glIndexi = _link_function('glIndexi', None, [GLint], None)

# /usr/include/GL/gl.h:981
glIndexs = _link_function('glIndexs', None, [GLshort], None)

# /usr/include/GL/gl.h:982
glIndexub = _link_function('glIndexub', None, [GLubyte], None)

# /usr/include/GL/gl.h:984
glIndexdv = _link_function('glIndexdv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:985
glIndexfv = _link_function('glIndexfv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:986
glIndexiv = _link_function('glIndexiv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:987
glIndexsv = _link_function('glIndexsv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:988
glIndexubv = _link_function('glIndexubv', None, [POINTER(GLubyte)], None)

# /usr/include/GL/gl.h:990
glColor3b = _link_function('glColor3b', None, [GLbyte, GLbyte, GLbyte], None)

# /usr/include/GL/gl.h:991
glColor3d = _link_function('glColor3d', None, [GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:992
glColor3f = _link_function('glColor3f', None, [GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:993
glColor3i = _link_function('glColor3i', None, [GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:994
glColor3s = _link_function('glColor3s', None, [GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:995
glColor3ub = _link_function('glColor3ub', None, [GLubyte, GLubyte, GLubyte], None)

# /usr/include/GL/gl.h:996
glColor3ui = _link_function('glColor3ui', None, [GLuint, GLuint, GLuint], None)

# /usr/include/GL/gl.h:997
glColor3us = _link_function('glColor3us', None, [GLushort, GLushort, GLushort], None)

# /usr/include/GL/gl.h:999
glColor4b = _link_function('glColor4b', None, [GLbyte, GLbyte, GLbyte, GLbyte], None)

# /usr/include/GL/gl.h:1001
glColor4d = _link_function('glColor4d', None, [GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1003
glColor4f = _link_function('glColor4f', None, [GLfloat, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1005
glColor4i = _link_function('glColor4i', None, [GLint, GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1007
glColor4s = _link_function('glColor4s', None, [GLshort, GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1009
glColor4ub = _link_function('glColor4ub', None, [GLubyte, GLubyte, GLubyte, GLubyte], None)

# /usr/include/GL/gl.h:1011
glColor4ui = _link_function('glColor4ui', None, [GLuint, GLuint, GLuint, GLuint], None)

# /usr/include/GL/gl.h:1013
glColor4us = _link_function('glColor4us', None, [GLushort, GLushort, GLushort, GLushort], None)

# /usr/include/GL/gl.h:1017
glColor3bv = _link_function('glColor3bv', None, [POINTER(GLbyte)], None)

# /usr/include/GL/gl.h:1018
glColor3dv = _link_function('glColor3dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1019
glColor3fv = _link_function('glColor3fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1020
glColor3iv = _link_function('glColor3iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1021
glColor3sv = _link_function('glColor3sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1022
glColor3ubv = _link_function('glColor3ubv', None, [POINTER(GLubyte)], None)

# /usr/include/GL/gl.h:1023
glColor3uiv = _link_function('glColor3uiv', None, [POINTER(GLuint)], None)

# /usr/include/GL/gl.h:1024
glColor3usv = _link_function('glColor3usv', None, [POINTER(GLushort)], None)

# /usr/include/GL/gl.h:1026
glColor4bv = _link_function('glColor4bv', None, [POINTER(GLbyte)], None)

# /usr/include/GL/gl.h:1027
glColor4dv = _link_function('glColor4dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1028
glColor4fv = _link_function('glColor4fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1029
glColor4iv = _link_function('glColor4iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1030
glColor4sv = _link_function('glColor4sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1031
glColor4ubv = _link_function('glColor4ubv', None, [POINTER(GLubyte)], None)

# /usr/include/GL/gl.h:1032
glColor4uiv = _link_function('glColor4uiv', None, [POINTER(GLuint)], None)

# /usr/include/GL/gl.h:1033
glColor4usv = _link_function('glColor4usv', None, [POINTER(GLushort)], None)

# /usr/include/GL/gl.h:1036
glTexCoord1d = _link_function('glTexCoord1d', None, [GLdouble], None)

# /usr/include/GL/gl.h:1037
glTexCoord1f = _link_function('glTexCoord1f', None, [GLfloat], None)

# /usr/include/GL/gl.h:1038
glTexCoord1i = _link_function('glTexCoord1i', None, [GLint], None)

# /usr/include/GL/gl.h:1039
glTexCoord1s = _link_function('glTexCoord1s', None, [GLshort], None)

# /usr/include/GL/gl.h:1041
glTexCoord2d = _link_function('glTexCoord2d', None, [GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1042
glTexCoord2f = _link_function('glTexCoord2f', None, [GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1043
glTexCoord2i = _link_function('glTexCoord2i', None, [GLint, GLint], None)

# /usr/include/GL/gl.h:1044
glTexCoord2s = _link_function('glTexCoord2s', None, [GLshort, GLshort], None)

# /usr/include/GL/gl.h:1046
glTexCoord3d = _link_function('glTexCoord3d', None, [GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1047
glTexCoord3f = _link_function('glTexCoord3f', None, [GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1048
glTexCoord3i = _link_function('glTexCoord3i', None, [GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1049
glTexCoord3s = _link_function('glTexCoord3s', None, [GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1051
glTexCoord4d = _link_function('glTexCoord4d', None, [GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1052
glTexCoord4f = _link_function('glTexCoord4f', None, [GLfloat, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1053
glTexCoord4i = _link_function('glTexCoord4i', None, [GLint, GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1054
glTexCoord4s = _link_function('glTexCoord4s', None, [GLshort, GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1056
glTexCoord1dv = _link_function('glTexCoord1dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1057
glTexCoord1fv = _link_function('glTexCoord1fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1058
glTexCoord1iv = _link_function('glTexCoord1iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1059
glTexCoord1sv = _link_function('glTexCoord1sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1061
glTexCoord2dv = _link_function('glTexCoord2dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1062
glTexCoord2fv = _link_function('glTexCoord2fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1063
glTexCoord2iv = _link_function('glTexCoord2iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1064
glTexCoord2sv = _link_function('glTexCoord2sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1066
glTexCoord3dv = _link_function('glTexCoord3dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1067
glTexCoord3fv = _link_function('glTexCoord3fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1068
glTexCoord3iv = _link_function('glTexCoord3iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1069
glTexCoord3sv = _link_function('glTexCoord3sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1071
glTexCoord4dv = _link_function('glTexCoord4dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1072
glTexCoord4fv = _link_function('glTexCoord4fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1073
glTexCoord4iv = _link_function('glTexCoord4iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1074
glTexCoord4sv = _link_function('glTexCoord4sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1077
glRasterPos2d = _link_function('glRasterPos2d', None, [GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1078
glRasterPos2f = _link_function('glRasterPos2f', None, [GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1079
glRasterPos2i = _link_function('glRasterPos2i', None, [GLint, GLint], None)

# /usr/include/GL/gl.h:1080
glRasterPos2s = _link_function('glRasterPos2s', None, [GLshort, GLshort], None)

# /usr/include/GL/gl.h:1082
glRasterPos3d = _link_function('glRasterPos3d', None, [GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1083
glRasterPos3f = _link_function('glRasterPos3f', None, [GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1084
glRasterPos3i = _link_function('glRasterPos3i', None, [GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1085
glRasterPos3s = _link_function('glRasterPos3s', None, [GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1087
glRasterPos4d = _link_function('glRasterPos4d', None, [GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1088
glRasterPos4f = _link_function('glRasterPos4f', None, [GLfloat, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1089
glRasterPos4i = _link_function('glRasterPos4i', None, [GLint, GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1090
glRasterPos4s = _link_function('glRasterPos4s', None, [GLshort, GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1092
glRasterPos2dv = _link_function('glRasterPos2dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1093
glRasterPos2fv = _link_function('glRasterPos2fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1094
glRasterPos2iv = _link_function('glRasterPos2iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1095
glRasterPos2sv = _link_function('glRasterPos2sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1097
glRasterPos3dv = _link_function('glRasterPos3dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1098
glRasterPos3fv = _link_function('glRasterPos3fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1099
glRasterPos3iv = _link_function('glRasterPos3iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1100
glRasterPos3sv = _link_function('glRasterPos3sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1102
glRasterPos4dv = _link_function('glRasterPos4dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1103
glRasterPos4fv = _link_function('glRasterPos4fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1104
glRasterPos4iv = _link_function('glRasterPos4iv', None, [POINTER(GLint)], None)

# /usr/include/GL/gl.h:1105
glRasterPos4sv = _link_function('glRasterPos4sv', None, [POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1108
glRectd = _link_function('glRectd', None, [GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1109
glRectf = _link_function('glRectf', None, [GLfloat, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1110
glRecti = _link_function('glRecti', None, [GLint, GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1111
glRects = _link_function('glRects', None, [GLshort, GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1114
glRectdv = _link_function('glRectdv', None, [POINTER(GLdouble), POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1115
glRectfv = _link_function('glRectfv', None, [POINTER(GLfloat), POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1116
glRectiv = _link_function('glRectiv', None, [POINTER(GLint), POINTER(GLint)], None)

# /usr/include/GL/gl.h:1117
glRectsv = _link_function('glRectsv', None, [POINTER(GLshort), POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1124
glVertexPointer = _link_function('glVertexPointer', None, [GLint, GLenum, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1127
glNormalPointer = _link_function('glNormalPointer', None, [GLenum, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1130
glColorPointer = _link_function('glColorPointer', None, [GLint, GLenum, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1133
glIndexPointer = _link_function('glIndexPointer', None, [GLenum, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1136
glTexCoordPointer = _link_function('glTexCoordPointer', None, [GLint, GLenum, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1139
glEdgeFlagPointer = _link_function('glEdgeFlagPointer', None, [GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1141
glGetPointerv = _link_function('glGetPointerv', None, [GLenum, POINTER(POINTER(GLvoid))], None)

# /usr/include/GL/gl.h:1143
glArrayElement = _link_function('glArrayElement', None, [GLint], None)

# /usr/include/GL/gl.h:1145
glDrawArrays = _link_function('glDrawArrays', None, [GLenum, GLint, GLsizei], None)

# /usr/include/GL/gl.h:1147
glDrawElements = _link_function('glDrawElements', None, [GLenum, GLsizei, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1150
glInterleavedArrays = _link_function('glInterleavedArrays', None, [GLenum, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1157
glShadeModel = _link_function('glShadeModel', None, [GLenum], None)

# /usr/include/GL/gl.h:1159
glLightf = _link_function('glLightf', None, [GLenum, GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1160
glLighti = _link_function('glLighti', None, [GLenum, GLenum, GLint], None)

# /usr/include/GL/gl.h:1161
glLightfv = _link_function('glLightfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1163
glLightiv = _link_function('glLightiv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1166
glGetLightfv = _link_function('glGetLightfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1168
glGetLightiv = _link_function('glGetLightiv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1171
glLightModelf = _link_function('glLightModelf', None, [GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1172
glLightModeli = _link_function('glLightModeli', None, [GLenum, GLint], None)

# /usr/include/GL/gl.h:1173
glLightModelfv = _link_function('glLightModelfv', None, [GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1174
glLightModeliv = _link_function('glLightModeliv', None, [GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1176
glMaterialf = _link_function('glMaterialf', None, [GLenum, GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1177
glMateriali = _link_function('glMateriali', None, [GLenum, GLenum, GLint], None)

# /usr/include/GL/gl.h:1178
glMaterialfv = _link_function('glMaterialfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1179
glMaterialiv = _link_function('glMaterialiv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1181
glGetMaterialfv = _link_function('glGetMaterialfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1182
glGetMaterialiv = _link_function('glGetMaterialiv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1184
glColorMaterial = _link_function('glColorMaterial', None, [GLenum, GLenum], None)

# /usr/include/GL/gl.h:1191
glPixelZoom = _link_function('glPixelZoom', None, [GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1193
glPixelStoref = _link_function('glPixelStoref', None, [GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1194
glPixelStorei = _link_function('glPixelStorei', None, [GLenum, GLint], None)

# /usr/include/GL/gl.h:1196
glPixelTransferf = _link_function('glPixelTransferf', None, [GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1197
glPixelTransferi = _link_function('glPixelTransferi', None, [GLenum, GLint], None)

# /usr/include/GL/gl.h:1199
glPixelMapfv = _link_function('glPixelMapfv', None, [GLenum, GLsizei, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1201
glPixelMapuiv = _link_function('glPixelMapuiv', None, [GLenum, GLsizei, POINTER(GLuint)], None)

# /usr/include/GL/gl.h:1203
glPixelMapusv = _link_function('glPixelMapusv', None, [GLenum, GLsizei, POINTER(GLushort)], None)

# /usr/include/GL/gl.h:1206
glGetPixelMapfv = _link_function('glGetPixelMapfv', None, [GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1207
glGetPixelMapuiv = _link_function('glGetPixelMapuiv', None, [GLenum, POINTER(GLuint)], None)

# /usr/include/GL/gl.h:1208
glGetPixelMapusv = _link_function('glGetPixelMapusv', None, [GLenum, POINTER(GLushort)], None)

# /usr/include/GL/gl.h:1210
glBitmap = _link_function('glBitmap', None, [GLsizei, GLsizei, GLfloat, GLfloat, GLfloat, GLfloat, POINTER(GLubyte)], None)

# /usr/include/GL/gl.h:1215
glReadPixels = _link_function('glReadPixels', None, [GLint, GLint, GLsizei, GLsizei, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1220
glDrawPixels = _link_function('glDrawPixels', None, [GLsizei, GLsizei, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1224
glCopyPixels = _link_function('glCopyPixels', None, [GLint, GLint, GLsizei, GLsizei, GLenum], None)

# /usr/include/GL/gl.h:1232
glStencilFunc = _link_function('glStencilFunc', None, [GLenum, GLint, GLuint], None)

# /usr/include/GL/gl.h:1234
glStencilMask = _link_function('glStencilMask', None, [GLuint], None)

# /usr/include/GL/gl.h:1236
glStencilOp = _link_function('glStencilOp', None, [GLenum, GLenum, GLenum], None)

# /usr/include/GL/gl.h:1238
glClearStencil = _link_function('glClearStencil', None, [GLint], None)

# /usr/include/GL/gl.h:1246
glTexGend = _link_function('glTexGend', None, [GLenum, GLenum, GLdouble], None)

# /usr/include/GL/gl.h:1247
glTexGenf = _link_function('glTexGenf', None, [GLenum, GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1248
glTexGeni = _link_function('glTexGeni', None, [GLenum, GLenum, GLint], None)

# /usr/include/GL/gl.h:1250
glTexGendv = _link_function('glTexGendv', None, [GLenum, GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1251
glTexGenfv = _link_function('glTexGenfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1252
glTexGeniv = _link_function('glTexGeniv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1254
glGetTexGendv = _link_function('glGetTexGendv', None, [GLenum, GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1255
glGetTexGenfv = _link_function('glGetTexGenfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1256
glGetTexGeniv = _link_function('glGetTexGeniv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1259
glTexEnvf = _link_function('glTexEnvf', None, [GLenum, GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1260
glTexEnvi = _link_function('glTexEnvi', None, [GLenum, GLenum, GLint], None)

# /usr/include/GL/gl.h:1262
glTexEnvfv = _link_function('glTexEnvfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1263
glTexEnviv = _link_function('glTexEnviv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1265
glGetTexEnvfv = _link_function('glGetTexEnvfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1266
glGetTexEnviv = _link_function('glGetTexEnviv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1269
glTexParameterf = _link_function('glTexParameterf', None, [GLenum, GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1270
glTexParameteri = _link_function('glTexParameteri', None, [GLenum, GLenum, GLint], None)

# /usr/include/GL/gl.h:1272
glTexParameterfv = _link_function('glTexParameterfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1274
glTexParameteriv = _link_function('glTexParameteriv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1277
glGetTexParameterfv = _link_function('glGetTexParameterfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1279
glGetTexParameteriv = _link_function('glGetTexParameteriv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1282
glGetTexLevelParameterfv = _link_function('glGetTexLevelParameterfv', None, [GLenum, GLint, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1284
glGetTexLevelParameteriv = _link_function('glGetTexLevelParameteriv', None, [GLenum, GLint, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1288
glTexImage1D = _link_function('glTexImage1D', None, [GLenum, GLint, GLint, GLsizei, GLint, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1294
glTexImage2D = _link_function('glTexImage2D', None, [GLenum, GLint, GLint, GLsizei, GLsizei, GLint, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1300
glGetTexImage = _link_function('glGetTexImage', None, [GLenum, GLint, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1307
glGenTextures = _link_function('glGenTextures', None, [GLsizei, POINTER(GLuint)], None)

# /usr/include/GL/gl.h:1309
glDeleteTextures = _link_function('glDeleteTextures', None, [GLsizei, POINTER(GLuint)], None)

# /usr/include/GL/gl.h:1311
glBindTexture = _link_function('glBindTexture', None, [GLenum, GLuint], None)

# /usr/include/GL/gl.h:1313
glPrioritizeTextures = _link_function('glPrioritizeTextures', None, [GLsizei, POINTER(GLuint), POINTER(GLclampf)], None)

# /usr/include/GL/gl.h:1317
glAreTexturesResident = _link_function('glAreTexturesResident', GLboolean, [GLsizei, POINTER(GLuint), POINTER(GLboolean)], None)

# /usr/include/GL/gl.h:1321
glIsTexture = _link_function('glIsTexture', GLboolean, [GLuint], None)

# /usr/include/GL/gl.h:1324
glTexSubImage1D = _link_function('glTexSubImage1D', None, [GLenum, GLint, GLint, GLsizei, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1330
glTexSubImage2D = _link_function('glTexSubImage2D', None, [GLenum, GLint, GLint, GLint, GLsizei, GLsizei, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1337
glCopyTexImage1D = _link_function('glCopyTexImage1D', None, [GLenum, GLint, GLenum, GLint, GLint, GLsizei, GLint], None)

# /usr/include/GL/gl.h:1343
glCopyTexImage2D = _link_function('glCopyTexImage2D', None, [GLenum, GLint, GLenum, GLint, GLint, GLsizei, GLsizei, GLint], None)

# /usr/include/GL/gl.h:1350
glCopyTexSubImage1D = _link_function('glCopyTexSubImage1D', None, [GLenum, GLint, GLint, GLint, GLint, GLsizei], None)

# /usr/include/GL/gl.h:1355
glCopyTexSubImage2D = _link_function('glCopyTexSubImage2D', None, [GLenum, GLint, GLint, GLint, GLint, GLint, GLsizei, GLsizei], None)

# /usr/include/GL/gl.h:1365
glMap1d = _link_function('glMap1d', None, [GLenum, GLdouble, GLdouble, GLint, GLint, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1368
glMap1f = _link_function('glMap1f', None, [GLenum, GLfloat, GLfloat, GLint, GLint, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1372
glMap2d = _link_function('glMap2d', None, [GLenum, GLdouble, GLdouble, GLint, GLint, GLdouble, GLdouble, GLint, GLint, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1376
glMap2f = _link_function('glMap2f', None, [GLenum, GLfloat, GLfloat, GLint, GLint, GLfloat, GLfloat, GLint, GLint, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1381
glGetMapdv = _link_function('glGetMapdv', None, [GLenum, GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1382
glGetMapfv = _link_function('glGetMapfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1383
glGetMapiv = _link_function('glGetMapiv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1385
glEvalCoord1d = _link_function('glEvalCoord1d', None, [GLdouble], None)

# /usr/include/GL/gl.h:1386
glEvalCoord1f = _link_function('glEvalCoord1f', None, [GLfloat], None)

# /usr/include/GL/gl.h:1388
glEvalCoord1dv = _link_function('glEvalCoord1dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1389
glEvalCoord1fv = _link_function('glEvalCoord1fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1391
glEvalCoord2d = _link_function('glEvalCoord2d', None, [GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1392
glEvalCoord2f = _link_function('glEvalCoord2f', None, [GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1394
glEvalCoord2dv = _link_function('glEvalCoord2dv', None, [POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1395
glEvalCoord2fv = _link_function('glEvalCoord2fv', None, [POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1397
glMapGrid1d = _link_function('glMapGrid1d', None, [GLint, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1398
glMapGrid1f = _link_function('glMapGrid1f', None, [GLint, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1400
glMapGrid2d = _link_function('glMapGrid2d', None, [GLint, GLdouble, GLdouble, GLint, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1402
glMapGrid2f = _link_function('glMapGrid2f', None, [GLint, GLfloat, GLfloat, GLint, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1405
glEvalPoint1 = _link_function('glEvalPoint1', None, [GLint], None)

# /usr/include/GL/gl.h:1407
glEvalPoint2 = _link_function('glEvalPoint2', None, [GLint, GLint], None)

# /usr/include/GL/gl.h:1409
glEvalMesh1 = _link_function('glEvalMesh1', None, [GLenum, GLint, GLint], None)

# /usr/include/GL/gl.h:1411
glEvalMesh2 = _link_function('glEvalMesh2', None, [GLenum, GLint, GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1418
glFogf = _link_function('glFogf', None, [GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1420
glFogi = _link_function('glFogi', None, [GLenum, GLint], None)

# /usr/include/GL/gl.h:1422
glFogfv = _link_function('glFogfv', None, [GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1424
glFogiv = _link_function('glFogiv', None, [GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1431
glFeedbackBuffer = _link_function('glFeedbackBuffer', None, [GLsizei, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1433
glPassThrough = _link_function('glPassThrough', None, [GLfloat], None)

# /usr/include/GL/gl.h:1435
glSelectBuffer = _link_function('glSelectBuffer', None, [GLsizei, POINTER(GLuint)], None)

# /usr/include/GL/gl.h:1437
glInitNames = _link_function('glInitNames', None, [], None)

# /usr/include/GL/gl.h:1439
glLoadName = _link_function('glLoadName', None, [GLuint], None)

# /usr/include/GL/gl.h:1441
glPushName = _link_function('glPushName', None, [GLuint], None)

# /usr/include/GL/gl.h:1443
glPopName = _link_function('glPopName', None, [], None)

GL_RESCALE_NORMAL = 32826 	# /usr/include/GL/gl.h:1451
GL_CLAMP_TO_EDGE = 33071 	# /usr/include/GL/gl.h:1452
GL_MAX_ELEMENTS_VERTICES = 33000 	# /usr/include/GL/gl.h:1453
GL_MAX_ELEMENTS_INDICES = 33001 	# /usr/include/GL/gl.h:1454
GL_BGR = 32992 	# /usr/include/GL/gl.h:1455
GL_BGRA = 32993 	# /usr/include/GL/gl.h:1456
GL_UNSIGNED_BYTE_3_3_2 = 32818 	# /usr/include/GL/gl.h:1457
GL_UNSIGNED_BYTE_2_3_3_REV = 33634 	# /usr/include/GL/gl.h:1458
GL_UNSIGNED_SHORT_5_6_5 = 33635 	# /usr/include/GL/gl.h:1459
GL_UNSIGNED_SHORT_5_6_5_REV = 33636 	# /usr/include/GL/gl.h:1460
GL_UNSIGNED_SHORT_4_4_4_4 = 32819 	# /usr/include/GL/gl.h:1461
GL_UNSIGNED_SHORT_4_4_4_4_REV = 33637 	# /usr/include/GL/gl.h:1462
GL_UNSIGNED_SHORT_5_5_5_1 = 32820 	# /usr/include/GL/gl.h:1463
GL_UNSIGNED_SHORT_1_5_5_5_REV = 33638 	# /usr/include/GL/gl.h:1464
GL_UNSIGNED_INT_8_8_8_8 = 32821 	# /usr/include/GL/gl.h:1465
GL_UNSIGNED_INT_8_8_8_8_REV = 33639 	# /usr/include/GL/gl.h:1466
GL_UNSIGNED_INT_10_10_10_2 = 32822 	# /usr/include/GL/gl.h:1467
GL_UNSIGNED_INT_2_10_10_10_REV = 33640 	# /usr/include/GL/gl.h:1468
GL_LIGHT_MODEL_COLOR_CONTROL = 33272 	# /usr/include/GL/gl.h:1469
GL_SINGLE_COLOR = 33273 	# /usr/include/GL/gl.h:1470
GL_SEPARATE_SPECULAR_COLOR = 33274 	# /usr/include/GL/gl.h:1471
GL_TEXTURE_MIN_LOD = 33082 	# /usr/include/GL/gl.h:1472
GL_TEXTURE_MAX_LOD = 33083 	# /usr/include/GL/gl.h:1473
GL_TEXTURE_BASE_LEVEL = 33084 	# /usr/include/GL/gl.h:1474
GL_TEXTURE_MAX_LEVEL = 33085 	# /usr/include/GL/gl.h:1475
GL_SMOOTH_POINT_SIZE_RANGE = 2834 	# /usr/include/GL/gl.h:1476
GL_SMOOTH_POINT_SIZE_GRANULARITY = 2835 	# /usr/include/GL/gl.h:1477
GL_SMOOTH_LINE_WIDTH_RANGE = 2850 	# /usr/include/GL/gl.h:1478
GL_SMOOTH_LINE_WIDTH_GRANULARITY = 2851 	# /usr/include/GL/gl.h:1479
GL_ALIASED_POINT_SIZE_RANGE = 33901 	# /usr/include/GL/gl.h:1480
GL_ALIASED_LINE_WIDTH_RANGE = 33902 	# /usr/include/GL/gl.h:1481
GL_PACK_SKIP_IMAGES = 32875 	# /usr/include/GL/gl.h:1482
GL_PACK_IMAGE_HEIGHT = 32876 	# /usr/include/GL/gl.h:1483
GL_UNPACK_SKIP_IMAGES = 32877 	# /usr/include/GL/gl.h:1484
GL_UNPACK_IMAGE_HEIGHT = 32878 	# /usr/include/GL/gl.h:1485
GL_TEXTURE_3D = 32879 	# /usr/include/GL/gl.h:1486
GL_PROXY_TEXTURE_3D = 32880 	# /usr/include/GL/gl.h:1487
GL_TEXTURE_DEPTH = 32881 	# /usr/include/GL/gl.h:1488
GL_TEXTURE_WRAP_R = 32882 	# /usr/include/GL/gl.h:1489
GL_MAX_3D_TEXTURE_SIZE = 32883 	# /usr/include/GL/gl.h:1490
GL_TEXTURE_BINDING_3D = 32874 	# /usr/include/GL/gl.h:1491
# /usr/include/GL/gl.h:1493
glDrawRangeElements = _link_function('glDrawRangeElements', None, [GLenum, GLuint, GLuint, GLsizei, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1496
glTexImage3D = _link_function('glTexImage3D', None, [GLenum, GLint, GLint, GLsizei, GLsizei, GLsizei, GLint, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1503
glTexSubImage3D = _link_function('glTexSubImage3D', None, [GLenum, GLint, GLint, GLint, GLint, GLsizei, GLsizei, GLsizei, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1510
glCopyTexSubImage3D = _link_function('glCopyTexSubImage3D', None, [GLenum, GLint, GLint, GLint, GLint, GLint, GLint, GLsizei, GLsizei], None)

PFNGLDRAWRANGEELEMENTSPROC = CFUNCTYPE(None, GLenum, GLuint, GLuint, GLsizei, GLenum, POINTER(GLvoid)) 	# /usr/include/GL/gl.h:1516
PFNGLTEXIMAGE3DPROC = CFUNCTYPE(None, GLenum, GLint, GLint, GLsizei, GLsizei, GLsizei, GLint, GLenum, GLenum, POINTER(GLvoid)) 	# /usr/include/GL/gl.h:1517
PFNGLTEXSUBIMAGE3DPROC = CFUNCTYPE(None, GLenum, GLint, GLint, GLint, GLint, GLsizei, GLsizei, GLsizei, GLenum, GLenum, POINTER(GLvoid)) 	# /usr/include/GL/gl.h:1518
PFNGLCOPYTEXSUBIMAGE3DPROC = CFUNCTYPE(None, GLenum, GLint, GLint, GLint, GLint, GLint, GLint, GLsizei, GLsizei) 	# /usr/include/GL/gl.h:1519
GL_CONSTANT_COLOR = 32769 	# /usr/include/GL/gl.h:1526
GL_ONE_MINUS_CONSTANT_COLOR = 32770 	# /usr/include/GL/gl.h:1527
GL_CONSTANT_ALPHA = 32771 	# /usr/include/GL/gl.h:1528
GL_ONE_MINUS_CONSTANT_ALPHA = 32772 	# /usr/include/GL/gl.h:1529
GL_COLOR_TABLE = 32976 	# /usr/include/GL/gl.h:1530
GL_POST_CONVOLUTION_COLOR_TABLE = 32977 	# /usr/include/GL/gl.h:1531
GL_POST_COLOR_MATRIX_COLOR_TABLE = 32978 	# /usr/include/GL/gl.h:1532
GL_PROXY_COLOR_TABLE = 32979 	# /usr/include/GL/gl.h:1533
GL_PROXY_POST_CONVOLUTION_COLOR_TABLE = 32980 	# /usr/include/GL/gl.h:1534
GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE = 32981 	# /usr/include/GL/gl.h:1535
GL_COLOR_TABLE_SCALE = 32982 	# /usr/include/GL/gl.h:1536
GL_COLOR_TABLE_BIAS = 32983 	# /usr/include/GL/gl.h:1537
GL_COLOR_TABLE_FORMAT = 32984 	# /usr/include/GL/gl.h:1538
GL_COLOR_TABLE_WIDTH = 32985 	# /usr/include/GL/gl.h:1539
GL_COLOR_TABLE_RED_SIZE = 32986 	# /usr/include/GL/gl.h:1540
GL_COLOR_TABLE_GREEN_SIZE = 32987 	# /usr/include/GL/gl.h:1541
GL_COLOR_TABLE_BLUE_SIZE = 32988 	# /usr/include/GL/gl.h:1542
GL_COLOR_TABLE_ALPHA_SIZE = 32989 	# /usr/include/GL/gl.h:1543
GL_COLOR_TABLE_LUMINANCE_SIZE = 32990 	# /usr/include/GL/gl.h:1544
GL_COLOR_TABLE_INTENSITY_SIZE = 32991 	# /usr/include/GL/gl.h:1545
GL_CONVOLUTION_1D = 32784 	# /usr/include/GL/gl.h:1546
GL_CONVOLUTION_2D = 32785 	# /usr/include/GL/gl.h:1547
GL_SEPARABLE_2D = 32786 	# /usr/include/GL/gl.h:1548
GL_CONVOLUTION_BORDER_MODE = 32787 	# /usr/include/GL/gl.h:1549
GL_CONVOLUTION_FILTER_SCALE = 32788 	# /usr/include/GL/gl.h:1550
GL_CONVOLUTION_FILTER_BIAS = 32789 	# /usr/include/GL/gl.h:1551
GL_REDUCE = 32790 	# /usr/include/GL/gl.h:1552
GL_CONVOLUTION_FORMAT = 32791 	# /usr/include/GL/gl.h:1553
GL_CONVOLUTION_WIDTH = 32792 	# /usr/include/GL/gl.h:1554
GL_CONVOLUTION_HEIGHT = 32793 	# /usr/include/GL/gl.h:1555
GL_MAX_CONVOLUTION_WIDTH = 32794 	# /usr/include/GL/gl.h:1556
GL_MAX_CONVOLUTION_HEIGHT = 32795 	# /usr/include/GL/gl.h:1557
GL_POST_CONVOLUTION_RED_SCALE = 32796 	# /usr/include/GL/gl.h:1558
GL_POST_CONVOLUTION_GREEN_SCALE = 32797 	# /usr/include/GL/gl.h:1559
GL_POST_CONVOLUTION_BLUE_SCALE = 32798 	# /usr/include/GL/gl.h:1560
GL_POST_CONVOLUTION_ALPHA_SCALE = 32799 	# /usr/include/GL/gl.h:1561
GL_POST_CONVOLUTION_RED_BIAS = 32800 	# /usr/include/GL/gl.h:1562
GL_POST_CONVOLUTION_GREEN_BIAS = 32801 	# /usr/include/GL/gl.h:1563
GL_POST_CONVOLUTION_BLUE_BIAS = 32802 	# /usr/include/GL/gl.h:1564
GL_POST_CONVOLUTION_ALPHA_BIAS = 32803 	# /usr/include/GL/gl.h:1565
GL_CONSTANT_BORDER = 33105 	# /usr/include/GL/gl.h:1566
GL_REPLICATE_BORDER = 33107 	# /usr/include/GL/gl.h:1567
GL_CONVOLUTION_BORDER_COLOR = 33108 	# /usr/include/GL/gl.h:1568
GL_COLOR_MATRIX = 32945 	# /usr/include/GL/gl.h:1569
GL_COLOR_MATRIX_STACK_DEPTH = 32946 	# /usr/include/GL/gl.h:1570
GL_MAX_COLOR_MATRIX_STACK_DEPTH = 32947 	# /usr/include/GL/gl.h:1571
GL_POST_COLOR_MATRIX_RED_SCALE = 32948 	# /usr/include/GL/gl.h:1572
GL_POST_COLOR_MATRIX_GREEN_SCALE = 32949 	# /usr/include/GL/gl.h:1573
GL_POST_COLOR_MATRIX_BLUE_SCALE = 32950 	# /usr/include/GL/gl.h:1574
GL_POST_COLOR_MATRIX_ALPHA_SCALE = 32951 	# /usr/include/GL/gl.h:1575
GL_POST_COLOR_MATRIX_RED_BIAS = 32952 	# /usr/include/GL/gl.h:1576
GL_POST_COLOR_MATRIX_GREEN_BIAS = 32953 	# /usr/include/GL/gl.h:1577
GL_POST_COLOR_MATRIX_BLUE_BIAS = 32954 	# /usr/include/GL/gl.h:1578
GL_POST_COLOR_MATRIX_ALPHA_BIAS = 32955 	# /usr/include/GL/gl.h:1579
GL_HISTOGRAM = 32804 	# /usr/include/GL/gl.h:1580
GL_PROXY_HISTOGRAM = 32805 	# /usr/include/GL/gl.h:1581
GL_HISTOGRAM_WIDTH = 32806 	# /usr/include/GL/gl.h:1582
GL_HISTOGRAM_FORMAT = 32807 	# /usr/include/GL/gl.h:1583
GL_HISTOGRAM_RED_SIZE = 32808 	# /usr/include/GL/gl.h:1584
GL_HISTOGRAM_GREEN_SIZE = 32809 	# /usr/include/GL/gl.h:1585
GL_HISTOGRAM_BLUE_SIZE = 32810 	# /usr/include/GL/gl.h:1586
GL_HISTOGRAM_ALPHA_SIZE = 32811 	# /usr/include/GL/gl.h:1587
GL_HISTOGRAM_LUMINANCE_SIZE = 32812 	# /usr/include/GL/gl.h:1588
GL_HISTOGRAM_SINK = 32813 	# /usr/include/GL/gl.h:1589
GL_MINMAX = 32814 	# /usr/include/GL/gl.h:1590
GL_MINMAX_FORMAT = 32815 	# /usr/include/GL/gl.h:1591
GL_MINMAX_SINK = 32816 	# /usr/include/GL/gl.h:1592
GL_TABLE_TOO_LARGE = 32817 	# /usr/include/GL/gl.h:1593
GL_BLEND_EQUATION = 32777 	# /usr/include/GL/gl.h:1594
GL_MIN = 32775 	# /usr/include/GL/gl.h:1595
GL_MAX = 32776 	# /usr/include/GL/gl.h:1596
GL_FUNC_ADD = 32774 	# /usr/include/GL/gl.h:1597
GL_FUNC_SUBTRACT = 32778 	# /usr/include/GL/gl.h:1598
GL_FUNC_REVERSE_SUBTRACT = 32779 	# /usr/include/GL/gl.h:1599
GL_BLEND_COLOR = 32773 	# /usr/include/GL/gl.h:1600
# /usr/include/GL/gl.h:1603
glColorTable = _link_function('glColorTable', None, [GLenum, GLenum, GLsizei, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1607
glColorSubTable = _link_function('glColorSubTable', None, [GLenum, GLsizei, GLsizei, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1612
glColorTableParameteriv = _link_function('glColorTableParameteriv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1615
glColorTableParameterfv = _link_function('glColorTableParameterfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1618
glCopyColorSubTable = _link_function('glCopyColorSubTable', None, [GLenum, GLsizei, GLint, GLint, GLsizei], None)

# /usr/include/GL/gl.h:1621
glCopyColorTable = _link_function('glCopyColorTable', None, [GLenum, GLenum, GLint, GLint, GLsizei], None)

# /usr/include/GL/gl.h:1624
glGetColorTable = _link_function('glGetColorTable', None, [GLenum, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1627
glGetColorTableParameterfv = _link_function('glGetColorTableParameterfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1630
glGetColorTableParameteriv = _link_function('glGetColorTableParameteriv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1633
glBlendEquation = _link_function('glBlendEquation', None, [GLenum], None)

# /usr/include/GL/gl.h:1635
glBlendColor = _link_function('glBlendColor', None, [GLclampf, GLclampf, GLclampf, GLclampf], None)

# /usr/include/GL/gl.h:1638
glHistogram = _link_function('glHistogram', None, [GLenum, GLsizei, GLenum, GLboolean], None)

# /usr/include/GL/gl.h:1641
glResetHistogram = _link_function('glResetHistogram', None, [GLenum], None)

# /usr/include/GL/gl.h:1643
glGetHistogram = _link_function('glGetHistogram', None, [GLenum, GLboolean, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1647
glGetHistogramParameterfv = _link_function('glGetHistogramParameterfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1650
glGetHistogramParameteriv = _link_function('glGetHistogramParameteriv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1653
glMinmax = _link_function('glMinmax', None, [GLenum, GLenum, GLboolean], None)

# /usr/include/GL/gl.h:1656
glResetMinmax = _link_function('glResetMinmax', None, [GLenum], None)

# /usr/include/GL/gl.h:1658
glGetMinmax = _link_function('glGetMinmax', None, [GLenum, GLboolean, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1662
glGetMinmaxParameterfv = _link_function('glGetMinmaxParameterfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1665
glGetMinmaxParameteriv = _link_function('glGetMinmaxParameteriv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1668
glConvolutionFilter1D = _link_function('glConvolutionFilter1D', None, [GLenum, GLenum, GLsizei, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1672
glConvolutionFilter2D = _link_function('glConvolutionFilter2D', None, [GLenum, GLenum, GLsizei, GLsizei, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1676
glConvolutionParameterf = _link_function('glConvolutionParameterf', None, [GLenum, GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1679
glConvolutionParameterfv = _link_function('glConvolutionParameterfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1682
glConvolutionParameteri = _link_function('glConvolutionParameteri', None, [GLenum, GLenum, GLint], None)

# /usr/include/GL/gl.h:1685
glConvolutionParameteriv = _link_function('glConvolutionParameteriv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1688
glCopyConvolutionFilter1D = _link_function('glCopyConvolutionFilter1D', None, [GLenum, GLenum, GLint, GLint, GLsizei], None)

# /usr/include/GL/gl.h:1691
glCopyConvolutionFilter2D = _link_function('glCopyConvolutionFilter2D', None, [GLenum, GLenum, GLint, GLint, GLsizei, GLsizei], None)

# /usr/include/GL/gl.h:1695
glGetConvolutionFilter = _link_function('glGetConvolutionFilter', None, [GLenum, GLenum, GLenum, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1698
glGetConvolutionParameterfv = _link_function('glGetConvolutionParameterfv', None, [GLenum, GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1701
glGetConvolutionParameteriv = _link_function('glGetConvolutionParameteriv', None, [GLenum, GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1704
glSeparableFilter2D = _link_function('glSeparableFilter2D', None, [GLenum, GLenum, GLsizei, GLsizei, GLenum, GLenum, POINTER(GLvoid), POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1708
glGetSeparableFilter = _link_function('glGetSeparableFilter', None, [GLenum, GLenum, GLenum, POINTER(GLvoid), POINTER(GLvoid), POINTER(GLvoid)], None)

GL_TEXTURE0 = 33984 	# /usr/include/GL/gl.h:1719
GL_TEXTURE1 = 33985 	# /usr/include/GL/gl.h:1720
GL_TEXTURE2 = 33986 	# /usr/include/GL/gl.h:1721
GL_TEXTURE3 = 33987 	# /usr/include/GL/gl.h:1722
GL_TEXTURE4 = 33988 	# /usr/include/GL/gl.h:1723
GL_TEXTURE5 = 33989 	# /usr/include/GL/gl.h:1724
GL_TEXTURE6 = 33990 	# /usr/include/GL/gl.h:1725
GL_TEXTURE7 = 33991 	# /usr/include/GL/gl.h:1726
GL_TEXTURE8 = 33992 	# /usr/include/GL/gl.h:1727
GL_TEXTURE9 = 33993 	# /usr/include/GL/gl.h:1728
GL_TEXTURE10 = 33994 	# /usr/include/GL/gl.h:1729
GL_TEXTURE11 = 33995 	# /usr/include/GL/gl.h:1730
GL_TEXTURE12 = 33996 	# /usr/include/GL/gl.h:1731
GL_TEXTURE13 = 33997 	# /usr/include/GL/gl.h:1732
GL_TEXTURE14 = 33998 	# /usr/include/GL/gl.h:1733
GL_TEXTURE15 = 33999 	# /usr/include/GL/gl.h:1734
GL_TEXTURE16 = 34000 	# /usr/include/GL/gl.h:1735
GL_TEXTURE17 = 34001 	# /usr/include/GL/gl.h:1736
GL_TEXTURE18 = 34002 	# /usr/include/GL/gl.h:1737
GL_TEXTURE19 = 34003 	# /usr/include/GL/gl.h:1738
GL_TEXTURE20 = 34004 	# /usr/include/GL/gl.h:1739
GL_TEXTURE21 = 34005 	# /usr/include/GL/gl.h:1740
GL_TEXTURE22 = 34006 	# /usr/include/GL/gl.h:1741
GL_TEXTURE23 = 34007 	# /usr/include/GL/gl.h:1742
GL_TEXTURE24 = 34008 	# /usr/include/GL/gl.h:1743
GL_TEXTURE25 = 34009 	# /usr/include/GL/gl.h:1744
GL_TEXTURE26 = 34010 	# /usr/include/GL/gl.h:1745
GL_TEXTURE27 = 34011 	# /usr/include/GL/gl.h:1746
GL_TEXTURE28 = 34012 	# /usr/include/GL/gl.h:1747
GL_TEXTURE29 = 34013 	# /usr/include/GL/gl.h:1748
GL_TEXTURE30 = 34014 	# /usr/include/GL/gl.h:1749
GL_TEXTURE31 = 34015 	# /usr/include/GL/gl.h:1750
GL_ACTIVE_TEXTURE = 34016 	# /usr/include/GL/gl.h:1751
GL_CLIENT_ACTIVE_TEXTURE = 34017 	# /usr/include/GL/gl.h:1752
GL_MAX_TEXTURE_UNITS = 34018 	# /usr/include/GL/gl.h:1753
GL_NORMAL_MAP = 34065 	# /usr/include/GL/gl.h:1755
GL_REFLECTION_MAP = 34066 	# /usr/include/GL/gl.h:1756
GL_TEXTURE_CUBE_MAP = 34067 	# /usr/include/GL/gl.h:1757
GL_TEXTURE_BINDING_CUBE_MAP = 34068 	# /usr/include/GL/gl.h:1758
GL_TEXTURE_CUBE_MAP_POSITIVE_X = 34069 	# /usr/include/GL/gl.h:1759
GL_TEXTURE_CUBE_MAP_NEGATIVE_X = 34070 	# /usr/include/GL/gl.h:1760
GL_TEXTURE_CUBE_MAP_POSITIVE_Y = 34071 	# /usr/include/GL/gl.h:1761
GL_TEXTURE_CUBE_MAP_NEGATIVE_Y = 34072 	# /usr/include/GL/gl.h:1762
GL_TEXTURE_CUBE_MAP_POSITIVE_Z = 34073 	# /usr/include/GL/gl.h:1763
GL_TEXTURE_CUBE_MAP_NEGATIVE_Z = 34074 	# /usr/include/GL/gl.h:1764
GL_PROXY_TEXTURE_CUBE_MAP = 34075 	# /usr/include/GL/gl.h:1765
GL_MAX_CUBE_MAP_TEXTURE_SIZE = 34076 	# /usr/include/GL/gl.h:1766
GL_COMPRESSED_ALPHA = 34025 	# /usr/include/GL/gl.h:1768
GL_COMPRESSED_LUMINANCE = 34026 	# /usr/include/GL/gl.h:1769
GL_COMPRESSED_LUMINANCE_ALPHA = 34027 	# /usr/include/GL/gl.h:1770
GL_COMPRESSED_INTENSITY = 34028 	# /usr/include/GL/gl.h:1771
GL_COMPRESSED_RGB = 34029 	# /usr/include/GL/gl.h:1772
GL_COMPRESSED_RGBA = 34030 	# /usr/include/GL/gl.h:1773
GL_TEXTURE_COMPRESSION_HINT = 34031 	# /usr/include/GL/gl.h:1774
GL_TEXTURE_COMPRESSED_IMAGE_SIZE = 34464 	# /usr/include/GL/gl.h:1775
GL_TEXTURE_COMPRESSED = 34465 	# /usr/include/GL/gl.h:1776
GL_NUM_COMPRESSED_TEXTURE_FORMATS = 34466 	# /usr/include/GL/gl.h:1777
GL_COMPRESSED_TEXTURE_FORMATS = 34467 	# /usr/include/GL/gl.h:1778
GL_MULTISAMPLE = 32925 	# /usr/include/GL/gl.h:1780
GL_SAMPLE_ALPHA_TO_COVERAGE = 32926 	# /usr/include/GL/gl.h:1781
GL_SAMPLE_ALPHA_TO_ONE = 32927 	# /usr/include/GL/gl.h:1782
GL_SAMPLE_COVERAGE = 32928 	# /usr/include/GL/gl.h:1783
GL_SAMPLE_BUFFERS = 32936 	# /usr/include/GL/gl.h:1784
GL_SAMPLES = 32937 	# /usr/include/GL/gl.h:1785
GL_SAMPLE_COVERAGE_VALUE = 32938 	# /usr/include/GL/gl.h:1786
GL_SAMPLE_COVERAGE_INVERT = 32939 	# /usr/include/GL/gl.h:1787
GL_MULTISAMPLE_BIT = 536870912 	# /usr/include/GL/gl.h:1788
GL_TRANSPOSE_MODELVIEW_MATRIX = 34019 	# /usr/include/GL/gl.h:1790
GL_TRANSPOSE_PROJECTION_MATRIX = 34020 	# /usr/include/GL/gl.h:1791
GL_TRANSPOSE_TEXTURE_MATRIX = 34021 	# /usr/include/GL/gl.h:1792
GL_TRANSPOSE_COLOR_MATRIX = 34022 	# /usr/include/GL/gl.h:1793
GL_COMBINE = 34160 	# /usr/include/GL/gl.h:1795
GL_COMBINE_RGB = 34161 	# /usr/include/GL/gl.h:1796
GL_COMBINE_ALPHA = 34162 	# /usr/include/GL/gl.h:1797
GL_SOURCE0_RGB = 34176 	# /usr/include/GL/gl.h:1798
GL_SOURCE1_RGB = 34177 	# /usr/include/GL/gl.h:1799
GL_SOURCE2_RGB = 34178 	# /usr/include/GL/gl.h:1800
GL_SOURCE0_ALPHA = 34184 	# /usr/include/GL/gl.h:1801
GL_SOURCE1_ALPHA = 34185 	# /usr/include/GL/gl.h:1802
GL_SOURCE2_ALPHA = 34186 	# /usr/include/GL/gl.h:1803
GL_OPERAND0_RGB = 34192 	# /usr/include/GL/gl.h:1804
GL_OPERAND1_RGB = 34193 	# /usr/include/GL/gl.h:1805
GL_OPERAND2_RGB = 34194 	# /usr/include/GL/gl.h:1806
GL_OPERAND0_ALPHA = 34200 	# /usr/include/GL/gl.h:1807
GL_OPERAND1_ALPHA = 34201 	# /usr/include/GL/gl.h:1808
GL_OPERAND2_ALPHA = 34202 	# /usr/include/GL/gl.h:1809
GL_RGB_SCALE = 34163 	# /usr/include/GL/gl.h:1810
GL_ADD_SIGNED = 34164 	# /usr/include/GL/gl.h:1811
GL_INTERPOLATE = 34165 	# /usr/include/GL/gl.h:1812
GL_SUBTRACT = 34023 	# /usr/include/GL/gl.h:1813
GL_CONSTANT = 34166 	# /usr/include/GL/gl.h:1814
GL_PRIMARY_COLOR = 34167 	# /usr/include/GL/gl.h:1815
GL_PREVIOUS = 34168 	# /usr/include/GL/gl.h:1816
GL_DOT3_RGB = 34478 	# /usr/include/GL/gl.h:1818
GL_DOT3_RGBA = 34479 	# /usr/include/GL/gl.h:1819
GL_CLAMP_TO_BORDER = 33069 	# /usr/include/GL/gl.h:1821
# /usr/include/GL/gl.h:1823
glActiveTexture = _link_function('glActiveTexture', None, [GLenum], None)

# /usr/include/GL/gl.h:1825
glClientActiveTexture = _link_function('glClientActiveTexture', None, [GLenum], None)

# /usr/include/GL/gl.h:1827
glCompressedTexImage1D = _link_function('glCompressedTexImage1D', None, [GLenum, GLint, GLenum, GLsizei, GLint, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1829
glCompressedTexImage2D = _link_function('glCompressedTexImage2D', None, [GLenum, GLint, GLenum, GLsizei, GLsizei, GLint, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1831
glCompressedTexImage3D = _link_function('glCompressedTexImage3D', None, [GLenum, GLint, GLenum, GLsizei, GLsizei, GLsizei, GLint, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1833
glCompressedTexSubImage1D = _link_function('glCompressedTexSubImage1D', None, [GLenum, GLint, GLint, GLsizei, GLenum, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1835
glCompressedTexSubImage2D = _link_function('glCompressedTexSubImage2D', None, [GLenum, GLint, GLint, GLint, GLsizei, GLsizei, GLenum, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1837
glCompressedTexSubImage3D = _link_function('glCompressedTexSubImage3D', None, [GLenum, GLint, GLint, GLint, GLint, GLsizei, GLsizei, GLsizei, GLenum, GLsizei, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1839
glGetCompressedTexImage = _link_function('glGetCompressedTexImage', None, [GLenum, GLint, POINTER(GLvoid)], None)

# /usr/include/GL/gl.h:1841
glMultiTexCoord1d = _link_function('glMultiTexCoord1d', None, [GLenum, GLdouble], None)

# /usr/include/GL/gl.h:1843
glMultiTexCoord1dv = _link_function('glMultiTexCoord1dv', None, [GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1845
glMultiTexCoord1f = _link_function('glMultiTexCoord1f', None, [GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1847
glMultiTexCoord1fv = _link_function('glMultiTexCoord1fv', None, [GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1849
glMultiTexCoord1i = _link_function('glMultiTexCoord1i', None, [GLenum, GLint], None)

# /usr/include/GL/gl.h:1851
glMultiTexCoord1iv = _link_function('glMultiTexCoord1iv', None, [GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1853
glMultiTexCoord1s = _link_function('glMultiTexCoord1s', None, [GLenum, GLshort], None)

# /usr/include/GL/gl.h:1855
glMultiTexCoord1sv = _link_function('glMultiTexCoord1sv', None, [GLenum, POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1857
glMultiTexCoord2d = _link_function('glMultiTexCoord2d', None, [GLenum, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1859
glMultiTexCoord2dv = _link_function('glMultiTexCoord2dv', None, [GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1861
glMultiTexCoord2f = _link_function('glMultiTexCoord2f', None, [GLenum, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1863
glMultiTexCoord2fv = _link_function('glMultiTexCoord2fv', None, [GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1865
glMultiTexCoord2i = _link_function('glMultiTexCoord2i', None, [GLenum, GLint, GLint], None)

# /usr/include/GL/gl.h:1867
glMultiTexCoord2iv = _link_function('glMultiTexCoord2iv', None, [GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1869
glMultiTexCoord2s = _link_function('glMultiTexCoord2s', None, [GLenum, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1871
glMultiTexCoord2sv = _link_function('glMultiTexCoord2sv', None, [GLenum, POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1873
glMultiTexCoord3d = _link_function('glMultiTexCoord3d', None, [GLenum, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1875
glMultiTexCoord3dv = _link_function('glMultiTexCoord3dv', None, [GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1877
glMultiTexCoord3f = _link_function('glMultiTexCoord3f', None, [GLenum, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1879
glMultiTexCoord3fv = _link_function('glMultiTexCoord3fv', None, [GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1881
glMultiTexCoord3i = _link_function('glMultiTexCoord3i', None, [GLenum, GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1883
glMultiTexCoord3iv = _link_function('glMultiTexCoord3iv', None, [GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1885
glMultiTexCoord3s = _link_function('glMultiTexCoord3s', None, [GLenum, GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1887
glMultiTexCoord3sv = _link_function('glMultiTexCoord3sv', None, [GLenum, POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1889
glMultiTexCoord4d = _link_function('glMultiTexCoord4d', None, [GLenum, GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1891
glMultiTexCoord4dv = _link_function('glMultiTexCoord4dv', None, [GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1893
glMultiTexCoord4f = _link_function('glMultiTexCoord4f', None, [GLenum, GLfloat, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1895
glMultiTexCoord4fv = _link_function('glMultiTexCoord4fv', None, [GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1897
glMultiTexCoord4i = _link_function('glMultiTexCoord4i', None, [GLenum, GLint, GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1899
glMultiTexCoord4iv = _link_function('glMultiTexCoord4iv', None, [GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1901
glMultiTexCoord4s = _link_function('glMultiTexCoord4s', None, [GLenum, GLshort, GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1903
glMultiTexCoord4sv = _link_function('glMultiTexCoord4sv', None, [GLenum, POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1906
glLoadTransposeMatrixd = _link_function('glLoadTransposeMatrixd', None, [GLdouble * 16], None)

# /usr/include/GL/gl.h:1908
glLoadTransposeMatrixf = _link_function('glLoadTransposeMatrixf', None, [GLfloat * 16], None)

# /usr/include/GL/gl.h:1910
glMultTransposeMatrixd = _link_function('glMultTransposeMatrixd', None, [GLdouble * 16], None)

# /usr/include/GL/gl.h:1912
glMultTransposeMatrixf = _link_function('glMultTransposeMatrixf', None, [GLfloat * 16], None)

# /usr/include/GL/gl.h:1914
glSampleCoverage = _link_function('glSampleCoverage', None, [GLclampf, GLboolean], None)

PFNGLACTIVETEXTUREPROC = CFUNCTYPE(None, GLenum) 	# /usr/include/GL/gl.h:1917
PFNGLSAMPLECOVERAGEPROC = CFUNCTYPE(None, GLclampf, GLboolean) 	# /usr/include/GL/gl.h:1918
PFNGLCOMPRESSEDTEXIMAGE3DPROC = CFUNCTYPE(None, GLenum, GLint, GLenum, GLsizei, GLsizei, GLsizei, GLint, GLsizei, POINTER(GLvoid)) 	# /usr/include/GL/gl.h:1919
PFNGLCOMPRESSEDTEXIMAGE2DPROC = CFUNCTYPE(None, GLenum, GLint, GLenum, GLsizei, GLsizei, GLint, GLsizei, POINTER(GLvoid)) 	# /usr/include/GL/gl.h:1920
PFNGLCOMPRESSEDTEXIMAGE1DPROC = CFUNCTYPE(None, GLenum, GLint, GLenum, GLsizei, GLint, GLsizei, POINTER(GLvoid)) 	# /usr/include/GL/gl.h:1921
PFNGLCOMPRESSEDTEXSUBIMAGE3DPROC = CFUNCTYPE(None, GLenum, GLint, GLint, GLint, GLint, GLsizei, GLsizei, GLsizei, GLenum, GLsizei, POINTER(GLvoid)) 	# /usr/include/GL/gl.h:1922
PFNGLCOMPRESSEDTEXSUBIMAGE2DPROC = CFUNCTYPE(None, GLenum, GLint, GLint, GLint, GLsizei, GLsizei, GLenum, GLsizei, POINTER(GLvoid)) 	# /usr/include/GL/gl.h:1923
PFNGLCOMPRESSEDTEXSUBIMAGE1DPROC = CFUNCTYPE(None, GLenum, GLint, GLint, GLsizei, GLenum, GLsizei, POINTER(GLvoid)) 	# /usr/include/GL/gl.h:1924
PFNGLGETCOMPRESSEDTEXIMAGEPROC = CFUNCTYPE(None, GLenum, GLint, POINTER(GLvoid)) 	# /usr/include/GL/gl.h:1925
GL_ARB_multitexture = 1 	# /usr/include/GL/gl.h:1933
GL_TEXTURE0_ARB = 33984 	# /usr/include/GL/gl.h:1935
GL_TEXTURE1_ARB = 33985 	# /usr/include/GL/gl.h:1936
GL_TEXTURE2_ARB = 33986 	# /usr/include/GL/gl.h:1937
GL_TEXTURE3_ARB = 33987 	# /usr/include/GL/gl.h:1938
GL_TEXTURE4_ARB = 33988 	# /usr/include/GL/gl.h:1939
GL_TEXTURE5_ARB = 33989 	# /usr/include/GL/gl.h:1940
GL_TEXTURE6_ARB = 33990 	# /usr/include/GL/gl.h:1941
GL_TEXTURE7_ARB = 33991 	# /usr/include/GL/gl.h:1942
GL_TEXTURE8_ARB = 33992 	# /usr/include/GL/gl.h:1943
GL_TEXTURE9_ARB = 33993 	# /usr/include/GL/gl.h:1944
GL_TEXTURE10_ARB = 33994 	# /usr/include/GL/gl.h:1945
GL_TEXTURE11_ARB = 33995 	# /usr/include/GL/gl.h:1946
GL_TEXTURE12_ARB = 33996 	# /usr/include/GL/gl.h:1947
GL_TEXTURE13_ARB = 33997 	# /usr/include/GL/gl.h:1948
GL_TEXTURE14_ARB = 33998 	# /usr/include/GL/gl.h:1949
GL_TEXTURE15_ARB = 33999 	# /usr/include/GL/gl.h:1950
GL_TEXTURE16_ARB = 34000 	# /usr/include/GL/gl.h:1951
GL_TEXTURE17_ARB = 34001 	# /usr/include/GL/gl.h:1952
GL_TEXTURE18_ARB = 34002 	# /usr/include/GL/gl.h:1953
GL_TEXTURE19_ARB = 34003 	# /usr/include/GL/gl.h:1954
GL_TEXTURE20_ARB = 34004 	# /usr/include/GL/gl.h:1955
GL_TEXTURE21_ARB = 34005 	# /usr/include/GL/gl.h:1956
GL_TEXTURE22_ARB = 34006 	# /usr/include/GL/gl.h:1957
GL_TEXTURE23_ARB = 34007 	# /usr/include/GL/gl.h:1958
GL_TEXTURE24_ARB = 34008 	# /usr/include/GL/gl.h:1959
GL_TEXTURE25_ARB = 34009 	# /usr/include/GL/gl.h:1960
GL_TEXTURE26_ARB = 34010 	# /usr/include/GL/gl.h:1961
GL_TEXTURE27_ARB = 34011 	# /usr/include/GL/gl.h:1962
GL_TEXTURE28_ARB = 34012 	# /usr/include/GL/gl.h:1963
GL_TEXTURE29_ARB = 34013 	# /usr/include/GL/gl.h:1964
GL_TEXTURE30_ARB = 34014 	# /usr/include/GL/gl.h:1965
GL_TEXTURE31_ARB = 34015 	# /usr/include/GL/gl.h:1966
GL_ACTIVE_TEXTURE_ARB = 34016 	# /usr/include/GL/gl.h:1967
GL_CLIENT_ACTIVE_TEXTURE_ARB = 34017 	# /usr/include/GL/gl.h:1968
GL_MAX_TEXTURE_UNITS_ARB = 34018 	# /usr/include/GL/gl.h:1969
# /usr/include/GL/gl.h:1971
glActiveTextureARB = _link_function('glActiveTextureARB', None, [GLenum], None)

# /usr/include/GL/gl.h:1972
glClientActiveTextureARB = _link_function('glClientActiveTextureARB', None, [GLenum], None)

# /usr/include/GL/gl.h:1973
glMultiTexCoord1dARB = _link_function('glMultiTexCoord1dARB', None, [GLenum, GLdouble], None)

# /usr/include/GL/gl.h:1974
glMultiTexCoord1dvARB = _link_function('glMultiTexCoord1dvARB', None, [GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1975
glMultiTexCoord1fARB = _link_function('glMultiTexCoord1fARB', None, [GLenum, GLfloat], None)

# /usr/include/GL/gl.h:1976
glMultiTexCoord1fvARB = _link_function('glMultiTexCoord1fvARB', None, [GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1977
glMultiTexCoord1iARB = _link_function('glMultiTexCoord1iARB', None, [GLenum, GLint], None)

# /usr/include/GL/gl.h:1978
glMultiTexCoord1ivARB = _link_function('glMultiTexCoord1ivARB', None, [GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1979
glMultiTexCoord1sARB = _link_function('glMultiTexCoord1sARB', None, [GLenum, GLshort], None)

# /usr/include/GL/gl.h:1980
glMultiTexCoord1svARB = _link_function('glMultiTexCoord1svARB', None, [GLenum, POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1981
glMultiTexCoord2dARB = _link_function('glMultiTexCoord2dARB', None, [GLenum, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1982
glMultiTexCoord2dvARB = _link_function('glMultiTexCoord2dvARB', None, [GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1983
glMultiTexCoord2fARB = _link_function('glMultiTexCoord2fARB', None, [GLenum, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1984
glMultiTexCoord2fvARB = _link_function('glMultiTexCoord2fvARB', None, [GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1985
glMultiTexCoord2iARB = _link_function('glMultiTexCoord2iARB', None, [GLenum, GLint, GLint], None)

# /usr/include/GL/gl.h:1986
glMultiTexCoord2ivARB = _link_function('glMultiTexCoord2ivARB', None, [GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1987
glMultiTexCoord2sARB = _link_function('glMultiTexCoord2sARB', None, [GLenum, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1988
glMultiTexCoord2svARB = _link_function('glMultiTexCoord2svARB', None, [GLenum, POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1989
glMultiTexCoord3dARB = _link_function('glMultiTexCoord3dARB', None, [GLenum, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1990
glMultiTexCoord3dvARB = _link_function('glMultiTexCoord3dvARB', None, [GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1991
glMultiTexCoord3fARB = _link_function('glMultiTexCoord3fARB', None, [GLenum, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:1992
glMultiTexCoord3fvARB = _link_function('glMultiTexCoord3fvARB', None, [GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:1993
glMultiTexCoord3iARB = _link_function('glMultiTexCoord3iARB', None, [GLenum, GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:1994
glMultiTexCoord3ivARB = _link_function('glMultiTexCoord3ivARB', None, [GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:1995
glMultiTexCoord3sARB = _link_function('glMultiTexCoord3sARB', None, [GLenum, GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:1996
glMultiTexCoord3svARB = _link_function('glMultiTexCoord3svARB', None, [GLenum, POINTER(GLshort)], None)

# /usr/include/GL/gl.h:1997
glMultiTexCoord4dARB = _link_function('glMultiTexCoord4dARB', None, [GLenum, GLdouble, GLdouble, GLdouble, GLdouble], None)

# /usr/include/GL/gl.h:1998
glMultiTexCoord4dvARB = _link_function('glMultiTexCoord4dvARB', None, [GLenum, POINTER(GLdouble)], None)

# /usr/include/GL/gl.h:1999
glMultiTexCoord4fARB = _link_function('glMultiTexCoord4fARB', None, [GLenum, GLfloat, GLfloat, GLfloat, GLfloat], None)

# /usr/include/GL/gl.h:2000
glMultiTexCoord4fvARB = _link_function('glMultiTexCoord4fvARB', None, [GLenum, POINTER(GLfloat)], None)

# /usr/include/GL/gl.h:2001
glMultiTexCoord4iARB = _link_function('glMultiTexCoord4iARB', None, [GLenum, GLint, GLint, GLint, GLint], None)

# /usr/include/GL/gl.h:2002
glMultiTexCoord4ivARB = _link_function('glMultiTexCoord4ivARB', None, [GLenum, POINTER(GLint)], None)

# /usr/include/GL/gl.h:2003
glMultiTexCoord4sARB = _link_function('glMultiTexCoord4sARB', None, [GLenum, GLshort, GLshort, GLshort, GLshort], None)

# /usr/include/GL/gl.h:2004
glMultiTexCoord4svARB = _link_function('glMultiTexCoord4svARB', None, [GLenum, POINTER(GLshort)], None)

PFNGLACTIVETEXTUREARBPROC = CFUNCTYPE(None, GLenum) 	# /usr/include/GL/gl.h:2006
PFNGLCLIENTACTIVETEXTUREARBPROC = CFUNCTYPE(None, GLenum) 	# /usr/include/GL/gl.h:2007
PFNGLMULTITEXCOORD1DARBPROC = CFUNCTYPE(None, GLenum, GLdouble) 	# /usr/include/GL/gl.h:2008
PFNGLMULTITEXCOORD1DVARBPROC = CFUNCTYPE(None, GLenum, POINTER(GLdouble)) 	# /usr/include/GL/gl.h:2009
PFNGLMULTITEXCOORD1FARBPROC = CFUNCTYPE(None, GLenum, GLfloat) 	# /usr/include/GL/gl.h:2010
PFNGLMULTITEXCOORD1FVARBPROC = CFUNCTYPE(None, GLenum, POINTER(GLfloat)) 	# /usr/include/GL/gl.h:2011
PFNGLMULTITEXCOORD1IARBPROC = CFUNCTYPE(None, GLenum, GLint) 	# /usr/include/GL/gl.h:2012
PFNGLMULTITEXCOORD1IVARBPROC = CFUNCTYPE(None, GLenum, POINTER(GLint)) 	# /usr/include/GL/gl.h:2013
PFNGLMULTITEXCOORD1SARBPROC = CFUNCTYPE(None, GLenum, GLshort) 	# /usr/include/GL/gl.h:2014
PFNGLMULTITEXCOORD1SVARBPROC = CFUNCTYPE(None, GLenum, POINTER(GLshort)) 	# /usr/include/GL/gl.h:2015
PFNGLMULTITEXCOORD2DARBPROC = CFUNCTYPE(None, GLenum, GLdouble, GLdouble) 	# /usr/include/GL/gl.h:2016
PFNGLMULTITEXCOORD2DVARBPROC = CFUNCTYPE(None, GLenum, POINTER(GLdouble)) 	# /usr/include/GL/gl.h:2017
PFNGLMULTITEXCOORD2FARBPROC = CFUNCTYPE(None, GLenum, GLfloat, GLfloat) 	# /usr/include/GL/gl.h:2018
PFNGLMULTITEXCOORD2FVARBPROC = CFUNCTYPE(None, GLenum, POINTER(GLfloat)) 	# /usr/include/GL/gl.h:2019
PFNGLMULTITEXCOORD2IARBPROC = CFUNCTYPE(None, GLenum, GLint, GLint) 	# /usr/include/GL/gl.h:2020
PFNGLMULTITEXCOORD2IVARBPROC = CFUNCTYPE(None, GLenum, POINTER(GLint)) 	# /usr/include/GL/gl.h:2021
PFNGLMULTITEXCOORD2SARBPROC = CFUNCTYPE(None, GLenum, GLshort, GLshort) 	# /usr/include/GL/gl.h:2022
PFNGLMULTITEXCOORD2SVARBPROC = CFUNCTYPE(None, GLenum, POINTER(GLshort)) 	# /usr/include/GL/gl.h:2023
PFNGLMULTITEXCOORD3DARBPROC = CFUNCTYPE(None, GLenum, GLdouble, GLdouble, GLdouble) 	# /usr/include/GL/gl.h:2024
PFNGLMULTITEXCOORD3DVARBPROC = CFUNCTYPE(None, GLenum, POINTER(GLdouble)) 	# /usr/include/GL/gl.h:2025
PFNGLMULTITEXCOORD3FARBPROC = CFUNCTYPE(None, GLenum, GLfloat, GLfloat, GLfloat) 	# /usr/include/GL/gl.h:2026
PFNGLMULTITEXCOORD3FVARBPROC = CFUNCTYPE(None, GLenum, POINTER(GLfloat)) 	# /usr/include/GL/gl.h:2027
PFNGLMULTITEXCOORD3IARBPROC = CFUNCTYPE(None, GLenum, GLint, GLint, GLint) 	# /usr/include/GL/gl.h:2028
PFNGLMULTITEXCOORD3IVARBPROC = CFUNCTYPE(None, GLenum, POINTER(GLint)) 	# /usr/include/GL/gl.h:2029
PFNGLMULTITEXCOORD3SARBPROC = CFUNCTYPE(None, GLenum, GLshort, GLshort, GLshort) 	# /usr/include/GL/gl.h:2030
PFNGLMULTITEXCOORD3SVARBPROC = CFUNCTYPE(None, GLenum, POINTER(GLshort)) 	# /usr/include/GL/gl.h:2031
PFNGLMULTITEXCOORD4DARBPROC = CFUNCTYPE(None, GLenum, GLdouble, GLdouble, GLdouble, GLdouble) 	# /usr/include/GL/gl.h:2032
PFNGLMULTITEXCOORD4DVARBPROC = CFUNCTYPE(None, GLenum, POINTER(GLdouble)) 	# /usr/include/GL/gl.h:2033
PFNGLMULTITEXCOORD4FARBPROC = CFUNCTYPE(None, GLenum, GLfloat, GLfloat, GLfloat, GLfloat) 	# /usr/include/GL/gl.h:2034
PFNGLMULTITEXCOORD4FVARBPROC = CFUNCTYPE(None, GLenum, POINTER(GLfloat)) 	# /usr/include/GL/gl.h:2035
PFNGLMULTITEXCOORD4IARBPROC = CFUNCTYPE(None, GLenum, GLint, GLint, GLint, GLint) 	# /usr/include/GL/gl.h:2036
PFNGLMULTITEXCOORD4IVARBPROC = CFUNCTYPE(None, GLenum, POINTER(GLint)) 	# /usr/include/GL/gl.h:2037
PFNGLMULTITEXCOORD4SARBPROC = CFUNCTYPE(None, GLenum, GLshort, GLshort, GLshort, GLshort) 	# /usr/include/GL/gl.h:2038
PFNGLMULTITEXCOORD4SVARBPROC = CFUNCTYPE(None, GLenum, POINTER(GLshort)) 	# /usr/include/GL/gl.h:2039
GL_MESA_packed_depth_stencil = 1 	# /usr/include/GL/gl.h:2066
GL_DEPTH_STENCIL_MESA = 34640 	# /usr/include/GL/gl.h:2068
GL_UNSIGNED_INT_24_8_MESA = 34641 	# /usr/include/GL/gl.h:2069
GL_UNSIGNED_INT_8_24_REV_MESA = 34642 	# /usr/include/GL/gl.h:2070
GL_UNSIGNED_SHORT_15_1_MESA = 34643 	# /usr/include/GL/gl.h:2071
GL_UNSIGNED_SHORT_1_15_REV_MESA = 34644 	# /usr/include/GL/gl.h:2072
GL_ATI_blend_equation_separate = 1 	# /usr/include/GL/gl.h:2078
GL_ALPHA_BLEND_EQUATION_ATI = 34877 	# /usr/include/GL/gl.h:2080
# /usr/include/GL/gl.h:2082
glBlendEquationSeparateATI = _link_function('glBlendEquationSeparateATI', None, [GLenum, GLenum], None)

PFNGLBLENDEQUATIONSEPARATEATIPROC = CFUNCTYPE(None, GLenum, GLenum) 	# /usr/include/GL/gl.h:2083
GLeglImageOES = POINTER(None) 	# /usr/include/GL/gl.h:2090
GL_OES_EGL_image = 1 	# /usr/include/GL/gl.h:2094
PFNGLEGLIMAGETARGETTEXTURE2DOESPROC = CFUNCTYPE(None, GLenum, GLeglImageOES) 	# /usr/include/GL/gl.h:2099
PFNGLEGLIMAGETARGETRENDERBUFFERSTORAGEOESPROC = CFUNCTYPE(None, GLenum, GLeglImageOES) 	# /usr/include/GL/gl.h:2100

__all__ = ['GL_VERSION_1_1', 'GL_VERSION_1_2', 'GL_VERSION_1_3',
'GL_ARB_imaging', 'GLenum', 'GLboolean', 'GLbitfield', 'GLvoid', 'GLbyte',
'GLshort', 'GLint', 'GLubyte', 'GLushort', 'GLuint', 'GLsizei', 'GLfloat',
'GLclampf', 'GLdouble', 'GLclampd', 'GL_FALSE', 'GL_TRUE', 'GL_BYTE',
'GL_UNSIGNED_BYTE', 'GL_SHORT', 'GL_UNSIGNED_SHORT', 'GL_INT',
'GL_UNSIGNED_INT', 'GL_FLOAT', 'GL_2_BYTES', 'GL_3_BYTES', 'GL_4_BYTES',
'GL_DOUBLE', 'GL_POINTS', 'GL_LINES', 'GL_LINE_LOOP', 'GL_LINE_STRIP',
'GL_TRIANGLES', 'GL_TRIANGLE_STRIP', 'GL_TRIANGLE_FAN', 'GL_QUADS',
'GL_QUAD_STRIP', 'GL_POLYGON', 'GL_VERTEX_ARRAY', 'GL_NORMAL_ARRAY',
'GL_COLOR_ARRAY', 'GL_INDEX_ARRAY', 'GL_TEXTURE_COORD_ARRAY',
'GL_EDGE_FLAG_ARRAY', 'GL_VERTEX_ARRAY_SIZE', 'GL_VERTEX_ARRAY_TYPE',
'GL_VERTEX_ARRAY_STRIDE', 'GL_NORMAL_ARRAY_TYPE', 'GL_NORMAL_ARRAY_STRIDE',
'GL_COLOR_ARRAY_SIZE', 'GL_COLOR_ARRAY_TYPE', 'GL_COLOR_ARRAY_STRIDE',
'GL_INDEX_ARRAY_TYPE', 'GL_INDEX_ARRAY_STRIDE', 'GL_TEXTURE_COORD_ARRAY_SIZE',
'GL_TEXTURE_COORD_ARRAY_TYPE', 'GL_TEXTURE_COORD_ARRAY_STRIDE',
'GL_EDGE_FLAG_ARRAY_STRIDE', 'GL_VERTEX_ARRAY_POINTER',
'GL_NORMAL_ARRAY_POINTER', 'GL_COLOR_ARRAY_POINTER', 'GL_INDEX_ARRAY_POINTER',
'GL_TEXTURE_COORD_ARRAY_POINTER', 'GL_EDGE_FLAG_ARRAY_POINTER', 'GL_V2F',
'GL_V3F', 'GL_C4UB_V2F', 'GL_C4UB_V3F', 'GL_C3F_V3F', 'GL_N3F_V3F',
'GL_C4F_N3F_V3F', 'GL_T2F_V3F', 'GL_T4F_V4F', 'GL_T2F_C4UB_V3F',
'GL_T2F_C3F_V3F', 'GL_T2F_N3F_V3F', 'GL_T2F_C4F_N3F_V3F',
'GL_T4F_C4F_N3F_V4F', 'GL_MATRIX_MODE', 'GL_MODELVIEW', 'GL_PROJECTION',
'GL_TEXTURE', 'GL_POINT_SMOOTH', 'GL_POINT_SIZE', 'GL_POINT_SIZE_GRANULARITY',
'GL_POINT_SIZE_RANGE', 'GL_LINE_SMOOTH', 'GL_LINE_STIPPLE',
'GL_LINE_STIPPLE_PATTERN', 'GL_LINE_STIPPLE_REPEAT', 'GL_LINE_WIDTH',
'GL_LINE_WIDTH_GRANULARITY', 'GL_LINE_WIDTH_RANGE', 'GL_POINT', 'GL_LINE',
'GL_FILL', 'GL_CW', 'GL_CCW', 'GL_FRONT', 'GL_BACK', 'GL_POLYGON_MODE',
'GL_POLYGON_SMOOTH', 'GL_POLYGON_STIPPLE', 'GL_EDGE_FLAG', 'GL_CULL_FACE',
'GL_CULL_FACE_MODE', 'GL_FRONT_FACE', 'GL_POLYGON_OFFSET_FACTOR',
'GL_POLYGON_OFFSET_UNITS', 'GL_POLYGON_OFFSET_POINT',
'GL_POLYGON_OFFSET_LINE', 'GL_POLYGON_OFFSET_FILL', 'GL_COMPILE',
'GL_COMPILE_AND_EXECUTE', 'GL_LIST_BASE', 'GL_LIST_INDEX', 'GL_LIST_MODE',
'GL_NEVER', 'GL_LESS', 'GL_EQUAL', 'GL_LEQUAL', 'GL_GREATER', 'GL_NOTEQUAL',
'GL_GEQUAL', 'GL_ALWAYS', 'GL_DEPTH_TEST', 'GL_DEPTH_BITS',
'GL_DEPTH_CLEAR_VALUE', 'GL_DEPTH_FUNC', 'GL_DEPTH_RANGE',
'GL_DEPTH_WRITEMASK', 'GL_DEPTH_COMPONENT', 'GL_LIGHTING', 'GL_LIGHT0',
'GL_LIGHT1', 'GL_LIGHT2', 'GL_LIGHT3', 'GL_LIGHT4', 'GL_LIGHT5', 'GL_LIGHT6',
'GL_LIGHT7', 'GL_SPOT_EXPONENT', 'GL_SPOT_CUTOFF', 'GL_CONSTANT_ATTENUATION',
'GL_LINEAR_ATTENUATION', 'GL_QUADRATIC_ATTENUATION', 'GL_AMBIENT',
'GL_DIFFUSE', 'GL_SPECULAR', 'GL_SHININESS', 'GL_EMISSION', 'GL_POSITION',
'GL_SPOT_DIRECTION', 'GL_AMBIENT_AND_DIFFUSE', 'GL_COLOR_INDEXES',
'GL_LIGHT_MODEL_TWO_SIDE', 'GL_LIGHT_MODEL_LOCAL_VIEWER',
'GL_LIGHT_MODEL_AMBIENT', 'GL_FRONT_AND_BACK', 'GL_SHADE_MODEL', 'GL_FLAT',
'GL_SMOOTH', 'GL_COLOR_MATERIAL', 'GL_COLOR_MATERIAL_FACE',
'GL_COLOR_MATERIAL_PARAMETER', 'GL_NORMALIZE', 'GL_CLIP_PLANE0',
'GL_CLIP_PLANE1', 'GL_CLIP_PLANE2', 'GL_CLIP_PLANE3', 'GL_CLIP_PLANE4',
'GL_CLIP_PLANE5', 'GL_ACCUM_RED_BITS', 'GL_ACCUM_GREEN_BITS',
'GL_ACCUM_BLUE_BITS', 'GL_ACCUM_ALPHA_BITS', 'GL_ACCUM_CLEAR_VALUE',
'GL_ACCUM', 'GL_ADD', 'GL_LOAD', 'GL_MULT', 'GL_RETURN', 'GL_ALPHA_TEST',
'GL_ALPHA_TEST_REF', 'GL_ALPHA_TEST_FUNC', 'GL_BLEND', 'GL_BLEND_SRC',
'GL_BLEND_DST', 'GL_ZERO', 'GL_ONE', 'GL_SRC_COLOR', 'GL_ONE_MINUS_SRC_COLOR',
'GL_SRC_ALPHA', 'GL_ONE_MINUS_SRC_ALPHA', 'GL_DST_ALPHA',
'GL_ONE_MINUS_DST_ALPHA', 'GL_DST_COLOR', 'GL_ONE_MINUS_DST_COLOR',
'GL_SRC_ALPHA_SATURATE', 'GL_FEEDBACK', 'GL_RENDER', 'GL_SELECT', 'GL_2D',
'GL_3D', 'GL_3D_COLOR', 'GL_3D_COLOR_TEXTURE', 'GL_4D_COLOR_TEXTURE',
'GL_POINT_TOKEN', 'GL_LINE_TOKEN', 'GL_LINE_RESET_TOKEN', 'GL_POLYGON_TOKEN',
'GL_BITMAP_TOKEN', 'GL_DRAW_PIXEL_TOKEN', 'GL_COPY_PIXEL_TOKEN',
'GL_PASS_THROUGH_TOKEN', 'GL_FEEDBACK_BUFFER_POINTER',
'GL_FEEDBACK_BUFFER_SIZE', 'GL_FEEDBACK_BUFFER_TYPE',
'GL_SELECTION_BUFFER_POINTER', 'GL_SELECTION_BUFFER_SIZE', 'GL_FOG',
'GL_FOG_MODE', 'GL_FOG_DENSITY', 'GL_FOG_COLOR', 'GL_FOG_INDEX',
'GL_FOG_START', 'GL_FOG_END', 'GL_LINEAR', 'GL_EXP', 'GL_EXP2', 'GL_LOGIC_OP',
'GL_INDEX_LOGIC_OP', 'GL_COLOR_LOGIC_OP', 'GL_LOGIC_OP_MODE', 'GL_CLEAR',
'GL_SET', 'GL_COPY', 'GL_COPY_INVERTED', 'GL_NOOP', 'GL_INVERT', 'GL_AND',
'GL_NAND', 'GL_OR', 'GL_NOR', 'GL_XOR', 'GL_EQUIV', 'GL_AND_REVERSE',
'GL_AND_INVERTED', 'GL_OR_REVERSE', 'GL_OR_INVERTED', 'GL_STENCIL_BITS',
'GL_STENCIL_TEST', 'GL_STENCIL_CLEAR_VALUE', 'GL_STENCIL_FUNC',
'GL_STENCIL_VALUE_MASK', 'GL_STENCIL_FAIL', 'GL_STENCIL_PASS_DEPTH_FAIL',
'GL_STENCIL_PASS_DEPTH_PASS', 'GL_STENCIL_REF', 'GL_STENCIL_WRITEMASK',
'GL_STENCIL_INDEX', 'GL_KEEP', 'GL_REPLACE', 'GL_INCR', 'GL_DECR', 'GL_NONE',
'GL_LEFT', 'GL_RIGHT', 'GL_FRONT_LEFT', 'GL_FRONT_RIGHT', 'GL_BACK_LEFT',
'GL_BACK_RIGHT', 'GL_AUX0', 'GL_AUX1', 'GL_AUX2', 'GL_AUX3', 'GL_COLOR_INDEX',
'GL_RED', 'GL_GREEN', 'GL_BLUE', 'GL_ALPHA', 'GL_LUMINANCE',
'GL_LUMINANCE_ALPHA', 'GL_ALPHA_BITS', 'GL_RED_BITS', 'GL_GREEN_BITS',
'GL_BLUE_BITS', 'GL_INDEX_BITS', 'GL_SUBPIXEL_BITS', 'GL_AUX_BUFFERS',
'GL_READ_BUFFER', 'GL_DRAW_BUFFER', 'GL_DOUBLEBUFFER', 'GL_STEREO',
'GL_BITMAP', 'GL_COLOR', 'GL_DEPTH', 'GL_STENCIL', 'GL_DITHER', 'GL_RGB',
'GL_RGBA', 'GL_MAX_LIST_NESTING', 'GL_MAX_EVAL_ORDER', 'GL_MAX_LIGHTS',
'GL_MAX_CLIP_PLANES', 'GL_MAX_TEXTURE_SIZE', 'GL_MAX_PIXEL_MAP_TABLE',
'GL_MAX_ATTRIB_STACK_DEPTH', 'GL_MAX_MODELVIEW_STACK_DEPTH',
'GL_MAX_NAME_STACK_DEPTH', 'GL_MAX_PROJECTION_STACK_DEPTH',
'GL_MAX_TEXTURE_STACK_DEPTH', 'GL_MAX_VIEWPORT_DIMS',
'GL_MAX_CLIENT_ATTRIB_STACK_DEPTH', 'GL_ATTRIB_STACK_DEPTH',
'GL_CLIENT_ATTRIB_STACK_DEPTH', 'GL_COLOR_CLEAR_VALUE', 'GL_COLOR_WRITEMASK',
'GL_CURRENT_INDEX', 'GL_CURRENT_COLOR', 'GL_CURRENT_NORMAL',
'GL_CURRENT_RASTER_COLOR', 'GL_CURRENT_RASTER_DISTANCE',
'GL_CURRENT_RASTER_INDEX', 'GL_CURRENT_RASTER_POSITION',
'GL_CURRENT_RASTER_TEXTURE_COORDS', 'GL_CURRENT_RASTER_POSITION_VALID',
'GL_CURRENT_TEXTURE_COORDS', 'GL_INDEX_CLEAR_VALUE', 'GL_INDEX_MODE',
'GL_INDEX_WRITEMASK', 'GL_MODELVIEW_MATRIX', 'GL_MODELVIEW_STACK_DEPTH',
'GL_NAME_STACK_DEPTH', 'GL_PROJECTION_MATRIX', 'GL_PROJECTION_STACK_DEPTH',
'GL_RENDER_MODE', 'GL_RGBA_MODE', 'GL_TEXTURE_MATRIX',
'GL_TEXTURE_STACK_DEPTH', 'GL_VIEWPORT', 'GL_AUTO_NORMAL', 'GL_MAP1_COLOR_4',
'GL_MAP1_INDEX', 'GL_MAP1_NORMAL', 'GL_MAP1_TEXTURE_COORD_1',
'GL_MAP1_TEXTURE_COORD_2', 'GL_MAP1_TEXTURE_COORD_3',
'GL_MAP1_TEXTURE_COORD_4', 'GL_MAP1_VERTEX_3', 'GL_MAP1_VERTEX_4',
'GL_MAP2_COLOR_4', 'GL_MAP2_INDEX', 'GL_MAP2_NORMAL',
'GL_MAP2_TEXTURE_COORD_1', 'GL_MAP2_TEXTURE_COORD_2',
'GL_MAP2_TEXTURE_COORD_3', 'GL_MAP2_TEXTURE_COORD_4', 'GL_MAP2_VERTEX_3',
'GL_MAP2_VERTEX_4', 'GL_MAP1_GRID_DOMAIN', 'GL_MAP1_GRID_SEGMENTS',
'GL_MAP2_GRID_DOMAIN', 'GL_MAP2_GRID_SEGMENTS', 'GL_COEFF', 'GL_ORDER',
'GL_DOMAIN', 'GL_PERSPECTIVE_CORRECTION_HINT', 'GL_POINT_SMOOTH_HINT',
'GL_LINE_SMOOTH_HINT', 'GL_POLYGON_SMOOTH_HINT', 'GL_FOG_HINT',
'GL_DONT_CARE', 'GL_FASTEST', 'GL_NICEST', 'GL_SCISSOR_BOX',
'GL_SCISSOR_TEST', 'GL_MAP_COLOR', 'GL_MAP_STENCIL', 'GL_INDEX_SHIFT',
'GL_INDEX_OFFSET', 'GL_RED_SCALE', 'GL_RED_BIAS', 'GL_GREEN_SCALE',
'GL_GREEN_BIAS', 'GL_BLUE_SCALE', 'GL_BLUE_BIAS', 'GL_ALPHA_SCALE',
'GL_ALPHA_BIAS', 'GL_DEPTH_SCALE', 'GL_DEPTH_BIAS',
'GL_PIXEL_MAP_S_TO_S_SIZE', 'GL_PIXEL_MAP_I_TO_I_SIZE',
'GL_PIXEL_MAP_I_TO_R_SIZE', 'GL_PIXEL_MAP_I_TO_G_SIZE',
'GL_PIXEL_MAP_I_TO_B_SIZE', 'GL_PIXEL_MAP_I_TO_A_SIZE',
'GL_PIXEL_MAP_R_TO_R_SIZE', 'GL_PIXEL_MAP_G_TO_G_SIZE',
'GL_PIXEL_MAP_B_TO_B_SIZE', 'GL_PIXEL_MAP_A_TO_A_SIZE', 'GL_PIXEL_MAP_S_TO_S',
'GL_PIXEL_MAP_I_TO_I', 'GL_PIXEL_MAP_I_TO_R', 'GL_PIXEL_MAP_I_TO_G',
'GL_PIXEL_MAP_I_TO_B', 'GL_PIXEL_MAP_I_TO_A', 'GL_PIXEL_MAP_R_TO_R',
'GL_PIXEL_MAP_G_TO_G', 'GL_PIXEL_MAP_B_TO_B', 'GL_PIXEL_MAP_A_TO_A',
'GL_PACK_ALIGNMENT', 'GL_PACK_LSB_FIRST', 'GL_PACK_ROW_LENGTH',
'GL_PACK_SKIP_PIXELS', 'GL_PACK_SKIP_ROWS', 'GL_PACK_SWAP_BYTES',
'GL_UNPACK_ALIGNMENT', 'GL_UNPACK_LSB_FIRST', 'GL_UNPACK_ROW_LENGTH',
'GL_UNPACK_SKIP_PIXELS', 'GL_UNPACK_SKIP_ROWS', 'GL_UNPACK_SWAP_BYTES',
'GL_ZOOM_X', 'GL_ZOOM_Y', 'GL_TEXTURE_ENV', 'GL_TEXTURE_ENV_MODE',
'GL_TEXTURE_1D', 'GL_TEXTURE_2D', 'GL_TEXTURE_WRAP_S', 'GL_TEXTURE_WRAP_T',
'GL_TEXTURE_MAG_FILTER', 'GL_TEXTURE_MIN_FILTER', 'GL_TEXTURE_ENV_COLOR',
'GL_TEXTURE_GEN_S', 'GL_TEXTURE_GEN_T', 'GL_TEXTURE_GEN_R',
'GL_TEXTURE_GEN_Q', 'GL_TEXTURE_GEN_MODE', 'GL_TEXTURE_BORDER_COLOR',
'GL_TEXTURE_WIDTH', 'GL_TEXTURE_HEIGHT', 'GL_TEXTURE_BORDER',
'GL_TEXTURE_COMPONENTS', 'GL_TEXTURE_RED_SIZE', 'GL_TEXTURE_GREEN_SIZE',
'GL_TEXTURE_BLUE_SIZE', 'GL_TEXTURE_ALPHA_SIZE', 'GL_TEXTURE_LUMINANCE_SIZE',
'GL_TEXTURE_INTENSITY_SIZE', 'GL_NEAREST_MIPMAP_NEAREST',
'GL_NEAREST_MIPMAP_LINEAR', 'GL_LINEAR_MIPMAP_NEAREST',
'GL_LINEAR_MIPMAP_LINEAR', 'GL_OBJECT_LINEAR', 'GL_OBJECT_PLANE',
'GL_EYE_LINEAR', 'GL_EYE_PLANE', 'GL_SPHERE_MAP', 'GL_DECAL', 'GL_MODULATE',
'GL_NEAREST', 'GL_REPEAT', 'GL_CLAMP', 'GL_S', 'GL_T', 'GL_R', 'GL_Q',
'GL_VENDOR', 'GL_RENDERER', 'GL_VERSION', 'GL_EXTENSIONS', 'GL_NO_ERROR',
'GL_INVALID_ENUM', 'GL_INVALID_VALUE', 'GL_INVALID_OPERATION',
'GL_STACK_OVERFLOW', 'GL_STACK_UNDERFLOW', 'GL_OUT_OF_MEMORY',
'GL_CURRENT_BIT', 'GL_POINT_BIT', 'GL_LINE_BIT', 'GL_POLYGON_BIT',
'GL_POLYGON_STIPPLE_BIT', 'GL_PIXEL_MODE_BIT', 'GL_LIGHTING_BIT',
'GL_FOG_BIT', 'GL_DEPTH_BUFFER_BIT', 'GL_ACCUM_BUFFER_BIT',
'GL_STENCIL_BUFFER_BIT', 'GL_VIEWPORT_BIT', 'GL_TRANSFORM_BIT',
'GL_ENABLE_BIT', 'GL_COLOR_BUFFER_BIT', 'GL_HINT_BIT', 'GL_EVAL_BIT',
'GL_LIST_BIT', 'GL_TEXTURE_BIT', 'GL_SCISSOR_BIT', 'GL_ALL_ATTRIB_BITS',
'GL_PROXY_TEXTURE_1D', 'GL_PROXY_TEXTURE_2D', 'GL_TEXTURE_PRIORITY',
'GL_TEXTURE_RESIDENT', 'GL_TEXTURE_BINDING_1D', 'GL_TEXTURE_BINDING_2D',
'GL_TEXTURE_INTERNAL_FORMAT', 'GL_ALPHA4', 'GL_ALPHA8', 'GL_ALPHA12',
'GL_ALPHA16', 'GL_LUMINANCE4', 'GL_LUMINANCE8', 'GL_LUMINANCE12',
'GL_LUMINANCE16', 'GL_LUMINANCE4_ALPHA4', 'GL_LUMINANCE6_ALPHA2',
'GL_LUMINANCE8_ALPHA8', 'GL_LUMINANCE12_ALPHA4', 'GL_LUMINANCE12_ALPHA12',
'GL_LUMINANCE16_ALPHA16', 'GL_INTENSITY', 'GL_INTENSITY4', 'GL_INTENSITY8',
'GL_INTENSITY12', 'GL_INTENSITY16', 'GL_R3_G3_B2', 'GL_RGB4', 'GL_RGB5',
'GL_RGB8', 'GL_RGB10', 'GL_RGB12', 'GL_RGB16', 'GL_RGBA2', 'GL_RGBA4',
'GL_RGB5_A1', 'GL_RGBA8', 'GL_RGB10_A2', 'GL_RGBA12', 'GL_RGBA16',
'GL_CLIENT_PIXEL_STORE_BIT', 'GL_CLIENT_VERTEX_ARRAY_BIT',
'GL_ALL_CLIENT_ATTRIB_BITS', 'GL_CLIENT_ALL_ATTRIB_BITS', 'glClearIndex',
'glClearColor', 'glClear', 'glIndexMask', 'glColorMask', 'glAlphaFunc',
'glBlendFunc', 'glLogicOp', 'glCullFace', 'glFrontFace', 'glPointSize',
'glLineWidth', 'glLineStipple', 'glPolygonMode', 'glPolygonOffset',
'glPolygonStipple', 'glGetPolygonStipple', 'glEdgeFlag', 'glEdgeFlagv',
'glScissor', 'glClipPlane', 'glGetClipPlane', 'glDrawBuffer', 'glReadBuffer',
'glEnable', 'glDisable', 'glIsEnabled', 'glEnableClientState',
'glDisableClientState', 'glGetBooleanv', 'glGetDoublev', 'glGetFloatv',
'glGetIntegerv', 'glPushAttrib', 'glPopAttrib', 'glPushClientAttrib',
'glPopClientAttrib', 'glRenderMode', 'glGetError', 'glGetString', 'glFinish',
'glFlush', 'glHint', 'glClearDepth', 'glDepthFunc', 'glDepthMask',
'glDepthRange', 'glClearAccum', 'glAccum', 'glMatrixMode', 'glOrtho',
'glFrustum', 'glViewport', 'glPushMatrix', 'glPopMatrix', 'glLoadIdentity',
'glLoadMatrixd', 'glLoadMatrixf', 'glMultMatrixd', 'glMultMatrixf',
'glRotated', 'glRotatef', 'glScaled', 'glScalef', 'glTranslated',
'glTranslatef', 'glIsList', 'glDeleteLists', 'glGenLists', 'glNewList',
'glEndList', 'glCallList', 'glCallLists', 'glListBase', 'glBegin', 'glEnd',
'glVertex2d', 'glVertex2f', 'glVertex2i', 'glVertex2s', 'glVertex3d',
'glVertex3f', 'glVertex3i', 'glVertex3s', 'glVertex4d', 'glVertex4f',
'glVertex4i', 'glVertex4s', 'glVertex2dv', 'glVertex2fv', 'glVertex2iv',
'glVertex2sv', 'glVertex3dv', 'glVertex3fv', 'glVertex3iv', 'glVertex3sv',
'glVertex4dv', 'glVertex4fv', 'glVertex4iv', 'glVertex4sv', 'glNormal3b',
'glNormal3d', 'glNormal3f', 'glNormal3i', 'glNormal3s', 'glNormal3bv',
'glNormal3dv', 'glNormal3fv', 'glNormal3iv', 'glNormal3sv', 'glIndexd',
'glIndexf', 'glIndexi', 'glIndexs', 'glIndexub', 'glIndexdv', 'glIndexfv',
'glIndexiv', 'glIndexsv', 'glIndexubv', 'glColor3b', 'glColor3d', 'glColor3f',
'glColor3i', 'glColor3s', 'glColor3ub', 'glColor3ui', 'glColor3us',
'glColor4b', 'glColor4d', 'glColor4f', 'glColor4i', 'glColor4s', 'glColor4ub',
'glColor4ui', 'glColor4us', 'glColor3bv', 'glColor3dv', 'glColor3fv',
'glColor3iv', 'glColor3sv', 'glColor3ubv', 'glColor3uiv', 'glColor3usv',
'glColor4bv', 'glColor4dv', 'glColor4fv', 'glColor4iv', 'glColor4sv',
'glColor4ubv', 'glColor4uiv', 'glColor4usv', 'glTexCoord1d', 'glTexCoord1f',
'glTexCoord1i', 'glTexCoord1s', 'glTexCoord2d', 'glTexCoord2f',
'glTexCoord2i', 'glTexCoord2s', 'glTexCoord3d', 'glTexCoord3f',
'glTexCoord3i', 'glTexCoord3s', 'glTexCoord4d', 'glTexCoord4f',
'glTexCoord4i', 'glTexCoord4s', 'glTexCoord1dv', 'glTexCoord1fv',
'glTexCoord1iv', 'glTexCoord1sv', 'glTexCoord2dv', 'glTexCoord2fv',
'glTexCoord2iv', 'glTexCoord2sv', 'glTexCoord3dv', 'glTexCoord3fv',
'glTexCoord3iv', 'glTexCoord3sv', 'glTexCoord4dv', 'glTexCoord4fv',
'glTexCoord4iv', 'glTexCoord4sv', 'glRasterPos2d', 'glRasterPos2f',
'glRasterPos2i', 'glRasterPos2s', 'glRasterPos3d', 'glRasterPos3f',
'glRasterPos3i', 'glRasterPos3s', 'glRasterPos4d', 'glRasterPos4f',
'glRasterPos4i', 'glRasterPos4s', 'glRasterPos2dv', 'glRasterPos2fv',
'glRasterPos2iv', 'glRasterPos2sv', 'glRasterPos3dv', 'glRasterPos3fv',
'glRasterPos3iv', 'glRasterPos3sv', 'glRasterPos4dv', 'glRasterPos4fv',
'glRasterPos4iv', 'glRasterPos4sv', 'glRectd', 'glRectf', 'glRecti',
'glRects', 'glRectdv', 'glRectfv', 'glRectiv', 'glRectsv', 'glVertexPointer',
'glNormalPointer', 'glColorPointer', 'glIndexPointer', 'glTexCoordPointer',
'glEdgeFlagPointer', 'glGetPointerv', 'glArrayElement', 'glDrawArrays',
'glDrawElements', 'glInterleavedArrays', 'glShadeModel', 'glLightf',
'glLighti', 'glLightfv', 'glLightiv', 'glGetLightfv', 'glGetLightiv',
'glLightModelf', 'glLightModeli', 'glLightModelfv', 'glLightModeliv',
'glMaterialf', 'glMateriali', 'glMaterialfv', 'glMaterialiv',
'glGetMaterialfv', 'glGetMaterialiv', 'glColorMaterial', 'glPixelZoom',
'glPixelStoref', 'glPixelStorei', 'glPixelTransferf', 'glPixelTransferi',
'glPixelMapfv', 'glPixelMapuiv', 'glPixelMapusv', 'glGetPixelMapfv',
'glGetPixelMapuiv', 'glGetPixelMapusv', 'glBitmap', 'glReadPixels',
'glDrawPixels', 'glCopyPixels', 'glStencilFunc', 'glStencilMask',
'glStencilOp', 'glClearStencil', 'glTexGend', 'glTexGenf', 'glTexGeni',
'glTexGendv', 'glTexGenfv', 'glTexGeniv', 'glGetTexGendv', 'glGetTexGenfv',
'glGetTexGeniv', 'glTexEnvf', 'glTexEnvi', 'glTexEnvfv', 'glTexEnviv',
'glGetTexEnvfv', 'glGetTexEnviv', 'glTexParameterf', 'glTexParameteri',
'glTexParameterfv', 'glTexParameteriv', 'glGetTexParameterfv',
'glGetTexParameteriv', 'glGetTexLevelParameterfv', 'glGetTexLevelParameteriv',
'glTexImage1D', 'glTexImage2D', 'glGetTexImage', 'glGenTextures',
'glDeleteTextures', 'glBindTexture', 'glPrioritizeTextures',
'glAreTexturesResident', 'glIsTexture', 'glTexSubImage1D', 'glTexSubImage2D',
'glCopyTexImage1D', 'glCopyTexImage2D', 'glCopyTexSubImage1D',
'glCopyTexSubImage2D', 'glMap1d', 'glMap1f', 'glMap2d', 'glMap2f',
'glGetMapdv', 'glGetMapfv', 'glGetMapiv', 'glEvalCoord1d', 'glEvalCoord1f',
'glEvalCoord1dv', 'glEvalCoord1fv', 'glEvalCoord2d', 'glEvalCoord2f',
'glEvalCoord2dv', 'glEvalCoord2fv', 'glMapGrid1d', 'glMapGrid1f',
'glMapGrid2d', 'glMapGrid2f', 'glEvalPoint1', 'glEvalPoint2', 'glEvalMesh1',
'glEvalMesh2', 'glFogf', 'glFogi', 'glFogfv', 'glFogiv', 'glFeedbackBuffer',
'glPassThrough', 'glSelectBuffer', 'glInitNames', 'glLoadName', 'glPushName',
'glPopName', 'GL_RESCALE_NORMAL', 'GL_CLAMP_TO_EDGE',
'GL_MAX_ELEMENTS_VERTICES', 'GL_MAX_ELEMENTS_INDICES', 'GL_BGR', 'GL_BGRA',
'GL_UNSIGNED_BYTE_3_3_2', 'GL_UNSIGNED_BYTE_2_3_3_REV',
'GL_UNSIGNED_SHORT_5_6_5', 'GL_UNSIGNED_SHORT_5_6_5_REV',
'GL_UNSIGNED_SHORT_4_4_4_4', 'GL_UNSIGNED_SHORT_4_4_4_4_REV',
'GL_UNSIGNED_SHORT_5_5_5_1', 'GL_UNSIGNED_SHORT_1_5_5_5_REV',
'GL_UNSIGNED_INT_8_8_8_8', 'GL_UNSIGNED_INT_8_8_8_8_REV',
'GL_UNSIGNED_INT_10_10_10_2', 'GL_UNSIGNED_INT_2_10_10_10_REV',
'GL_LIGHT_MODEL_COLOR_CONTROL', 'GL_SINGLE_COLOR',
'GL_SEPARATE_SPECULAR_COLOR', 'GL_TEXTURE_MIN_LOD', 'GL_TEXTURE_MAX_LOD',
'GL_TEXTURE_BASE_LEVEL', 'GL_TEXTURE_MAX_LEVEL', 'GL_SMOOTH_POINT_SIZE_RANGE',
'GL_SMOOTH_POINT_SIZE_GRANULARITY', 'GL_SMOOTH_LINE_WIDTH_RANGE',
'GL_SMOOTH_LINE_WIDTH_GRANULARITY', 'GL_ALIASED_POINT_SIZE_RANGE',
'GL_ALIASED_LINE_WIDTH_RANGE', 'GL_PACK_SKIP_IMAGES', 'GL_PACK_IMAGE_HEIGHT',
'GL_UNPACK_SKIP_IMAGES', 'GL_UNPACK_IMAGE_HEIGHT', 'GL_TEXTURE_3D',
'GL_PROXY_TEXTURE_3D', 'GL_TEXTURE_DEPTH', 'GL_TEXTURE_WRAP_R',
'GL_MAX_3D_TEXTURE_SIZE', 'GL_TEXTURE_BINDING_3D', 'glDrawRangeElements',
'glTexImage3D', 'glTexSubImage3D', 'glCopyTexSubImage3D',
'PFNGLDRAWRANGEELEMENTSPROC', 'PFNGLTEXIMAGE3DPROC', 'PFNGLTEXSUBIMAGE3DPROC',
'PFNGLCOPYTEXSUBIMAGE3DPROC', 'GL_CONSTANT_COLOR',
'GL_ONE_MINUS_CONSTANT_COLOR', 'GL_CONSTANT_ALPHA',
'GL_ONE_MINUS_CONSTANT_ALPHA', 'GL_COLOR_TABLE',
'GL_POST_CONVOLUTION_COLOR_TABLE', 'GL_POST_COLOR_MATRIX_COLOR_TABLE',
'GL_PROXY_COLOR_TABLE', 'GL_PROXY_POST_CONVOLUTION_COLOR_TABLE',
'GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE', 'GL_COLOR_TABLE_SCALE',
'GL_COLOR_TABLE_BIAS', 'GL_COLOR_TABLE_FORMAT', 'GL_COLOR_TABLE_WIDTH',
'GL_COLOR_TABLE_RED_SIZE', 'GL_COLOR_TABLE_GREEN_SIZE',
'GL_COLOR_TABLE_BLUE_SIZE', 'GL_COLOR_TABLE_ALPHA_SIZE',
'GL_COLOR_TABLE_LUMINANCE_SIZE', 'GL_COLOR_TABLE_INTENSITY_SIZE',
'GL_CONVOLUTION_1D', 'GL_CONVOLUTION_2D', 'GL_SEPARABLE_2D',
'GL_CONVOLUTION_BORDER_MODE', 'GL_CONVOLUTION_FILTER_SCALE',
'GL_CONVOLUTION_FILTER_BIAS', 'GL_REDUCE', 'GL_CONVOLUTION_FORMAT',
'GL_CONVOLUTION_WIDTH', 'GL_CONVOLUTION_HEIGHT', 'GL_MAX_CONVOLUTION_WIDTH',
'GL_MAX_CONVOLUTION_HEIGHT', 'GL_POST_CONVOLUTION_RED_SCALE',
'GL_POST_CONVOLUTION_GREEN_SCALE', 'GL_POST_CONVOLUTION_BLUE_SCALE',
'GL_POST_CONVOLUTION_ALPHA_SCALE', 'GL_POST_CONVOLUTION_RED_BIAS',
'GL_POST_CONVOLUTION_GREEN_BIAS', 'GL_POST_CONVOLUTION_BLUE_BIAS',
'GL_POST_CONVOLUTION_ALPHA_BIAS', 'GL_CONSTANT_BORDER', 'GL_REPLICATE_BORDER',
'GL_CONVOLUTION_BORDER_COLOR', 'GL_COLOR_MATRIX',
'GL_COLOR_MATRIX_STACK_DEPTH', 'GL_MAX_COLOR_MATRIX_STACK_DEPTH',
'GL_POST_COLOR_MATRIX_RED_SCALE', 'GL_POST_COLOR_MATRIX_GREEN_SCALE',
'GL_POST_COLOR_MATRIX_BLUE_SCALE', 'GL_POST_COLOR_MATRIX_ALPHA_SCALE',
'GL_POST_COLOR_MATRIX_RED_BIAS', 'GL_POST_COLOR_MATRIX_GREEN_BIAS',
'GL_POST_COLOR_MATRIX_BLUE_BIAS', 'GL_POST_COLOR_MATRIX_ALPHA_BIAS',
'GL_HISTOGRAM', 'GL_PROXY_HISTOGRAM', 'GL_HISTOGRAM_WIDTH',
'GL_HISTOGRAM_FORMAT', 'GL_HISTOGRAM_RED_SIZE', 'GL_HISTOGRAM_GREEN_SIZE',
'GL_HISTOGRAM_BLUE_SIZE', 'GL_HISTOGRAM_ALPHA_SIZE',
'GL_HISTOGRAM_LUMINANCE_SIZE', 'GL_HISTOGRAM_SINK', 'GL_MINMAX',
'GL_MINMAX_FORMAT', 'GL_MINMAX_SINK', 'GL_TABLE_TOO_LARGE',
'GL_BLEND_EQUATION', 'GL_MIN', 'GL_MAX', 'GL_FUNC_ADD', 'GL_FUNC_SUBTRACT',
'GL_FUNC_REVERSE_SUBTRACT', 'GL_BLEND_COLOR', 'glColorTable',
'glColorSubTable', 'glColorTableParameteriv', 'glColorTableParameterfv',
'glCopyColorSubTable', 'glCopyColorTable', 'glGetColorTable',
'glGetColorTableParameterfv', 'glGetColorTableParameteriv', 'glBlendEquation',
'glBlendColor', 'glHistogram', 'glResetHistogram', 'glGetHistogram',
'glGetHistogramParameterfv', 'glGetHistogramParameteriv', 'glMinmax',
'glResetMinmax', 'glGetMinmax', 'glGetMinmaxParameterfv',
'glGetMinmaxParameteriv', 'glConvolutionFilter1D', 'glConvolutionFilter2D',
'glConvolutionParameterf', 'glConvolutionParameterfv',
'glConvolutionParameteri', 'glConvolutionParameteriv',
'glCopyConvolutionFilter1D', 'glCopyConvolutionFilter2D',
'glGetConvolutionFilter', 'glGetConvolutionParameterfv',
'glGetConvolutionParameteriv', 'glSeparableFilter2D', 'glGetSeparableFilter',
'GL_TEXTURE0', 'GL_TEXTURE1', 'GL_TEXTURE2', 'GL_TEXTURE3', 'GL_TEXTURE4',
'GL_TEXTURE5', 'GL_TEXTURE6', 'GL_TEXTURE7', 'GL_TEXTURE8', 'GL_TEXTURE9',
'GL_TEXTURE10', 'GL_TEXTURE11', 'GL_TEXTURE12', 'GL_TEXTURE13',
'GL_TEXTURE14', 'GL_TEXTURE15', 'GL_TEXTURE16', 'GL_TEXTURE17',
'GL_TEXTURE18', 'GL_TEXTURE19', 'GL_TEXTURE20', 'GL_TEXTURE21',
'GL_TEXTURE22', 'GL_TEXTURE23', 'GL_TEXTURE24', 'GL_TEXTURE25',
'GL_TEXTURE26', 'GL_TEXTURE27', 'GL_TEXTURE28', 'GL_TEXTURE29',
'GL_TEXTURE30', 'GL_TEXTURE31', 'GL_ACTIVE_TEXTURE',
'GL_CLIENT_ACTIVE_TEXTURE', 'GL_MAX_TEXTURE_UNITS', 'GL_NORMAL_MAP',
'GL_REFLECTION_MAP', 'GL_TEXTURE_CUBE_MAP', 'GL_TEXTURE_BINDING_CUBE_MAP',
'GL_TEXTURE_CUBE_MAP_POSITIVE_X', 'GL_TEXTURE_CUBE_MAP_NEGATIVE_X',
'GL_TEXTURE_CUBE_MAP_POSITIVE_Y', 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Y',
'GL_TEXTURE_CUBE_MAP_POSITIVE_Z', 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Z',
'GL_PROXY_TEXTURE_CUBE_MAP', 'GL_MAX_CUBE_MAP_TEXTURE_SIZE',
'GL_COMPRESSED_ALPHA', 'GL_COMPRESSED_LUMINANCE',
'GL_COMPRESSED_LUMINANCE_ALPHA', 'GL_COMPRESSED_INTENSITY',
'GL_COMPRESSED_RGB', 'GL_COMPRESSED_RGBA', 'GL_TEXTURE_COMPRESSION_HINT',
'GL_TEXTURE_COMPRESSED_IMAGE_SIZE', 'GL_TEXTURE_COMPRESSED',
'GL_NUM_COMPRESSED_TEXTURE_FORMATS', 'GL_COMPRESSED_TEXTURE_FORMATS',
'GL_MULTISAMPLE', 'GL_SAMPLE_ALPHA_TO_COVERAGE', 'GL_SAMPLE_ALPHA_TO_ONE',
'GL_SAMPLE_COVERAGE', 'GL_SAMPLE_BUFFERS', 'GL_SAMPLES',
'GL_SAMPLE_COVERAGE_VALUE', 'GL_SAMPLE_COVERAGE_INVERT', 'GL_MULTISAMPLE_BIT',
'GL_TRANSPOSE_MODELVIEW_MATRIX', 'GL_TRANSPOSE_PROJECTION_MATRIX',
'GL_TRANSPOSE_TEXTURE_MATRIX', 'GL_TRANSPOSE_COLOR_MATRIX', 'GL_COMBINE',
'GL_COMBINE_RGB', 'GL_COMBINE_ALPHA', 'GL_SOURCE0_RGB', 'GL_SOURCE1_RGB',
'GL_SOURCE2_RGB', 'GL_SOURCE0_ALPHA', 'GL_SOURCE1_ALPHA', 'GL_SOURCE2_ALPHA',
'GL_OPERAND0_RGB', 'GL_OPERAND1_RGB', 'GL_OPERAND2_RGB', 'GL_OPERAND0_ALPHA',
'GL_OPERAND1_ALPHA', 'GL_OPERAND2_ALPHA', 'GL_RGB_SCALE', 'GL_ADD_SIGNED',
'GL_INTERPOLATE', 'GL_SUBTRACT', 'GL_CONSTANT', 'GL_PRIMARY_COLOR',
'GL_PREVIOUS', 'GL_DOT3_RGB', 'GL_DOT3_RGBA', 'GL_CLAMP_TO_BORDER',
'glActiveTexture', 'glClientActiveTexture', 'glCompressedTexImage1D',
'glCompressedTexImage2D', 'glCompressedTexImage3D',
'glCompressedTexSubImage1D', 'glCompressedTexSubImage2D',
'glCompressedTexSubImage3D', 'glGetCompressedTexImage', 'glMultiTexCoord1d',
'glMultiTexCoord1dv', 'glMultiTexCoord1f', 'glMultiTexCoord1fv',
'glMultiTexCoord1i', 'glMultiTexCoord1iv', 'glMultiTexCoord1s',
'glMultiTexCoord1sv', 'glMultiTexCoord2d', 'glMultiTexCoord2dv',
'glMultiTexCoord2f', 'glMultiTexCoord2fv', 'glMultiTexCoord2i',
'glMultiTexCoord2iv', 'glMultiTexCoord2s', 'glMultiTexCoord2sv',
'glMultiTexCoord3d', 'glMultiTexCoord3dv', 'glMultiTexCoord3f',
'glMultiTexCoord3fv', 'glMultiTexCoord3i', 'glMultiTexCoord3iv',
'glMultiTexCoord3s', 'glMultiTexCoord3sv', 'glMultiTexCoord4d',
'glMultiTexCoord4dv', 'glMultiTexCoord4f', 'glMultiTexCoord4fv',
'glMultiTexCoord4i', 'glMultiTexCoord4iv', 'glMultiTexCoord4s',
'glMultiTexCoord4sv', 'glLoadTransposeMatrixd', 'glLoadTransposeMatrixf',
'glMultTransposeMatrixd', 'glMultTransposeMatrixf', 'glSampleCoverage',
'PFNGLACTIVETEXTUREPROC', 'PFNGLSAMPLECOVERAGEPROC',
'PFNGLCOMPRESSEDTEXIMAGE3DPROC', 'PFNGLCOMPRESSEDTEXIMAGE2DPROC',
'PFNGLCOMPRESSEDTEXIMAGE1DPROC', 'PFNGLCOMPRESSEDTEXSUBIMAGE3DPROC',
'PFNGLCOMPRESSEDTEXSUBIMAGE2DPROC', 'PFNGLCOMPRESSEDTEXSUBIMAGE1DPROC',
'PFNGLGETCOMPRESSEDTEXIMAGEPROC', 'GL_ARB_multitexture', 'GL_TEXTURE0_ARB',
'GL_TEXTURE1_ARB', 'GL_TEXTURE2_ARB', 'GL_TEXTURE3_ARB', 'GL_TEXTURE4_ARB',
'GL_TEXTURE5_ARB', 'GL_TEXTURE6_ARB', 'GL_TEXTURE7_ARB', 'GL_TEXTURE8_ARB',
'GL_TEXTURE9_ARB', 'GL_TEXTURE10_ARB', 'GL_TEXTURE11_ARB', 'GL_TEXTURE12_ARB',
'GL_TEXTURE13_ARB', 'GL_TEXTURE14_ARB', 'GL_TEXTURE15_ARB',
'GL_TEXTURE16_ARB', 'GL_TEXTURE17_ARB', 'GL_TEXTURE18_ARB',
'GL_TEXTURE19_ARB', 'GL_TEXTURE20_ARB', 'GL_TEXTURE21_ARB',
'GL_TEXTURE22_ARB', 'GL_TEXTURE23_ARB', 'GL_TEXTURE24_ARB',
'GL_TEXTURE25_ARB', 'GL_TEXTURE26_ARB', 'GL_TEXTURE27_ARB',
'GL_TEXTURE28_ARB', 'GL_TEXTURE29_ARB', 'GL_TEXTURE30_ARB',
'GL_TEXTURE31_ARB', 'GL_ACTIVE_TEXTURE_ARB', 'GL_CLIENT_ACTIVE_TEXTURE_ARB',
'GL_MAX_TEXTURE_UNITS_ARB', 'glActiveTextureARB', 'glClientActiveTextureARB',
'glMultiTexCoord1dARB', 'glMultiTexCoord1dvARB', 'glMultiTexCoord1fARB',
'glMultiTexCoord1fvARB', 'glMultiTexCoord1iARB', 'glMultiTexCoord1ivARB',
'glMultiTexCoord1sARB', 'glMultiTexCoord1svARB', 'glMultiTexCoord2dARB',
'glMultiTexCoord2dvARB', 'glMultiTexCoord2fARB', 'glMultiTexCoord2fvARB',
'glMultiTexCoord2iARB', 'glMultiTexCoord2ivARB', 'glMultiTexCoord2sARB',
'glMultiTexCoord2svARB', 'glMultiTexCoord3dARB', 'glMultiTexCoord3dvARB',
'glMultiTexCoord3fARB', 'glMultiTexCoord3fvARB', 'glMultiTexCoord3iARB',
'glMultiTexCoord3ivARB', 'glMultiTexCoord3sARB', 'glMultiTexCoord3svARB',
'glMultiTexCoord4dARB', 'glMultiTexCoord4dvARB', 'glMultiTexCoord4fARB',
'glMultiTexCoord4fvARB', 'glMultiTexCoord4iARB', 'glMultiTexCoord4ivARB',
'glMultiTexCoord4sARB', 'glMultiTexCoord4svARB', 'PFNGLACTIVETEXTUREARBPROC',
'PFNGLCLIENTACTIVETEXTUREARBPROC', 'PFNGLMULTITEXCOORD1DARBPROC',
'PFNGLMULTITEXCOORD1DVARBPROC', 'PFNGLMULTITEXCOORD1FARBPROC',
'PFNGLMULTITEXCOORD1FVARBPROC', 'PFNGLMULTITEXCOORD1IARBPROC',
'PFNGLMULTITEXCOORD1IVARBPROC', 'PFNGLMULTITEXCOORD1SARBPROC',
'PFNGLMULTITEXCOORD1SVARBPROC', 'PFNGLMULTITEXCOORD2DARBPROC',
'PFNGLMULTITEXCOORD2DVARBPROC', 'PFNGLMULTITEXCOORD2FARBPROC',
'PFNGLMULTITEXCOORD2FVARBPROC', 'PFNGLMULTITEXCOORD2IARBPROC',
'PFNGLMULTITEXCOORD2IVARBPROC', 'PFNGLMULTITEXCOORD2SARBPROC',
'PFNGLMULTITEXCOORD2SVARBPROC', 'PFNGLMULTITEXCOORD3DARBPROC',
'PFNGLMULTITEXCOORD3DVARBPROC', 'PFNGLMULTITEXCOORD3FARBPROC',
'PFNGLMULTITEXCOORD3FVARBPROC', 'PFNGLMULTITEXCOORD3IARBPROC',
'PFNGLMULTITEXCOORD3IVARBPROC', 'PFNGLMULTITEXCOORD3SARBPROC',
'PFNGLMULTITEXCOORD3SVARBPROC', 'PFNGLMULTITEXCOORD4DARBPROC',
'PFNGLMULTITEXCOORD4DVARBPROC', 'PFNGLMULTITEXCOORD4FARBPROC',
'PFNGLMULTITEXCOORD4FVARBPROC', 'PFNGLMULTITEXCOORD4IARBPROC',
'PFNGLMULTITEXCOORD4IVARBPROC', 'PFNGLMULTITEXCOORD4SARBPROC',
'PFNGLMULTITEXCOORD4SVARBPROC', 'GL_MESA_packed_depth_stencil',
'GL_DEPTH_STENCIL_MESA', 'GL_UNSIGNED_INT_24_8_MESA',
'GL_UNSIGNED_INT_8_24_REV_MESA', 'GL_UNSIGNED_SHORT_15_1_MESA',
'GL_UNSIGNED_SHORT_1_15_REV_MESA', 'GL_ATI_blend_equation_separate',
'GL_ALPHA_BLEND_EQUATION_ATI', 'glBlendEquationSeparateATI',
'PFNGLBLENDEQUATIONSEPARATEATIPROC', 'GLeglImageOES', 'GL_OES_EGL_image',
'PFNGLEGLIMAGETARGETTEXTURE2DOESPROC',
'PFNGLEGLIMAGETARGETRENDERBUFFERSTORAGEOESPROC']
# END GENERATED CONTENT (do not edit above this line)






